@@ -124,8 +124,6 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Zerrenda hau ez da guztiz ikusten errendimendu arrazoiengatik. Fitxategiak zerrendan zehar nabigatzen duten heinean bistaratuko dira.",
     "File not found" : "Ez da fitxategia aurkitu",
     "_{count} selected_::_{count} selected_" : ["{count} hautatuta","{count} hautatuta"],
-    "Search everywhere …" : "Bilatu nonahi...",
-    "Search here …" : "Bilatu hemen...",
     "Search scope options" : "Bilaketa-eremuaren aukerak",
     "Search here" : "Bilatu hemen",
     "{usedQuotaByte} used" : "{usedQuotaByte} erabilita",
@@ -144,7 +142,6 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Ezin izan da fitxategi-izenen garbiketa egoera freskatu.",
     "Filename sanitization in progress." : "Fitxategi-izenen garbiketa martxan da.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Une honetan {totalUsers}kontuetatik {processedUsers}prozesatu dira.",
-    "Preparing …" : "Prestatzen...",
     "Refresh" : "Freskatu",
     "All files have been santized for Windows filename support." : "Fitxategi guztiak garbitu dira Windows-en fitxategi-izenaren onarpenerako.",
     "Some files could not be sanitized, please check your logs." : "Fitxategi batzuk ezin izan dira garbitu, begiratu erregistroak.",
@@ -159,7 +156,6 @@ OC.L10N.register(
     "Sanitize filenames" : "Garbitu fitxategi-izenak",
     "(starting)" : "(abiatzen)",
     "Fill template fields" : "Bete txantiloien eremuak",
-    "Submitting fields …" : "Bidaltzeko eremuak",
     "Submit" : "Bidali",
     "Choose a file or folder to transfer" : "Aukeratu fitxategi edo karpeta bat transferitzeko",
     "Transfer" : "Transferitu",
@@ -183,33 +179,9 @@ OC.L10N.register(
     "Do not show this dialog again." : "Ez erakutsi elkarrizketa hau berriro",
     "Select file or folder to link to" : "Hautatu estekatzeko fitxategia edo karpeta",
     "Choose {file}" : "Aukeratu {file}",
-    "Share" : "Partekatu",
-    "Shared by link" : "Esteka bidez partekatuta",
-    "Shared" : "Partekatuta",
-    "Switch to list view" : "Aldatu zerrenda ikuspegira",
-    "Switch to grid view" : "Aldatu sareta ikuspegira",
-    "The file could not be found" : "Fitxategiaren hodeia ez da aurkitu",
-    "Upload was cancelled by user" : "Igoera bertan behera utzi du erabiltzaileak",
-    "Not enough free space" : "Ez dago leku libre nahikorik",
-    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
-    "Error during upload: {message}" : "Errorea igotzean: {message}",
-    "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
-    "Unknown error during upload" : "Errore ezezaguna igotzean",
-    "Loading current folder" : "Uneko karpeta kargatzen",
-    "Retry" : "saiatu berriro",
-    "No files in here" : "Ez dago fitxategirik hemen",
-    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
-    "Go back" : "Atzera",
-    "Views" : "Ikuspegiak",
-    "Files settings" : "FItxategien ezarpenak",
-    "Your files" : "Zure fitxategiak",
-    "Open in files" : "Ireki Fitxategiak aplikazioan",
-    "File cannot be accessed" : "Ezin da fitxategia atzitu",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
-    "No search results for “{query}”" : "Ez da aurkitu emaitzarik “{query}” kontsultarentzat",
-    "Search for files" : "Bilatu fitxategiak",
     "Clipboard is not available" : "Arbela ez dago erabilgarri",
     "WebDAV URL copied" : "WebDAV URLa kopiatu da",
+    "Files settings" : "FItxategien ezarpenak",
     "General" : "Orokorra",
     "Default view" : "Ikuspegi lehenetsia",
     "All files" : "Fitxategi guztiak",
@@ -252,12 +224,24 @@ OC.L10N.register(
     "Toggle grid view" : "Txandakatu sareta ikuspegia",
     "Open file sidebar" : "Ireki alboko barra",
     "Show those shortcuts" : "Erakutsi lasterbide horiek",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria eman diezaioke.",
-    "Failed to toggle Windows filename support" : "Huts egin du Windows-en fitxategi-izenen onarpena aldatzeak",
-    "Files compatibility" : "Fitxategien bateragarritasuna",
-    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
+    "Share" : "Partekatu",
+    "Shared by link" : "Esteka bidez partekatuta",
+    "Shared" : "Partekatuta",
+    "Switch to list view" : "Aldatu zerrenda ikuspegira",
+    "Switch to grid view" : "Aldatu sareta ikuspegira",
+    "The file could not be found" : "Fitxategiaren hodeia ez da aurkitu",
+    "Upload was cancelled by user" : "Igoera bertan behera utzi du erabiltzaileak",
+    "Not enough free space" : "Ez dago leku libre nahikorik",
+    "Operation is blocked by access control" : "Sarbide kontrolak eragiketa blokeatu du",
+    "Error during upload: {message}" : "Errorea igotzean: {message}",
+    "Error during upload, status code {status}" : "Errore bat gertatu da igotzean, {status} egoera kodea",
+    "Unknown error during upload" : "Errore ezezaguna igotzean",
+    "Loading current folder" : "Uneko karpeta kargatzen",
+    "Retry" : "saiatu berriro",
+    "No files in here" : "Ez dago fitxategirik hemen",
+    "Upload some content or sync with your devices!" : "Igo edukiren bat edo sinkronizatu zure gailuekin!",
+    "Go back" : "Atzera",
+    "Views" : "Ikuspegiak",
     "You" : "Zu ",
     "Shared multiple times with different people" : "Hainbat aldiz partekatua pertsona ezberdinekin",
     "Unable to change the favorite state of the file" : "Ezin da fitxategiaren gogoko egoera aldatu",
@@ -266,14 +250,24 @@ OC.L10N.register(
     "Remove from favorites" : "Kendu gogokoetatik",
     "Add to favorites" : "Gehitu gogokoetara",
     "Tags" : "Etiketak",
+    "Your files" : "Zure fitxategiak",
+    "Open in files" : "Ireki Fitxategiak aplikazioan",
+    "File cannot be accessed" : "Ezin da fitxategia atzitu",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Ezin izan da fitxategia aurkitu edo ez duzu ikusteko baimenik. Eskatu bidaltzaileari partekatzeko.",
+    "No search results for “{query}”" : "Ez da aurkitu emaitzarik “{query}” kontsultarentzat",
+    "Search for files" : "Bilatu fitxategiak",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Baimendu fitxategi-izenak mugatzea, fitxategiak bezero guztiekin sinkroniza daitezkeela ziurtatzeko. Lehenespenez POSIX-en balio duten fitxategi-izen guztiak (adibidez, Linux edo macOS) onartzen dira.",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria eman diezaioke.",
+    "Failed to toggle Windows filename support" : "Huts egin du Windows-en fitxategi-izenen onarpena aldatzeak",
+    "Files compatibility" : "Fitxategien bateragarritasuna",
+    "Enforce Windows compatibility" : "Ezarri Windows bateragarritasuna",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Honek Windows sistemetan balio ez duten fitxategi-izenak blokeatuko ditu, adibidez, izen erreserbatuak edo karaktere bereziak erabiltzea. Baina honek ez du maiuskulak eta minuskulak bereizteko bateragarritasuna beteko.",
     "Blank" : "Hutsik",
     "Unable to create new file from template" : "Ezin da fitxategi berria sortu txantiloitik",
     "Pick a template for {name}" : "Hautatu {name}(r)entzako txantiloia",
     "Create a new file with the selected template" : "Sortu fitxategi berria hautatutako txantiloiarekin",
     "Creating file" : "Fitxategia sortzen",
     "Save as {displayName}" : "Gorde honela: {displayName}",
-    "Save as …" : "Gorde honela...",
-    "Converting files …" : "Fitxategiak bihurtzen...",
     "Failed to convert files: {message}" : "Huts egin du fitxategiak bihurtzeak: {message}",
     "All files failed to be converted" : "Huts egin du fitxategi guztiak bihurtzean",
     "One file could not be converted: {message}" : "Fitxategi bat ezin izan da bihurtu: {message}",
@@ -281,7 +275,6 @@ OC.L10N.register(
     "_One file successfully converted_::_%n files successfully converted_" : ["Fitxategi bat behar bezala bihurtu da","%n fitxategi behar bezala bihurtu dira"],
     "Files successfully converted" : "Fitxategiak behar bezala bihurtu dira",
     "Failed to convert files" : "Huts egin du fitxategien bihurtzeak",
-    "Converting file …" : "Fitxategia bihurtzen...",
     "File successfully converted" : "Fitxategia behar bezala bihurtu da",
     "Failed to convert file: {message}" : "Fitxategi honen bihurtzeak huts egin du: {message}",
     "Failed to convert file" : "Huts egin du fitxategiaren bihurtzeak",
@@ -302,8 +295,6 @@ OC.L10N.register(
     "Download" : "Deskargatu",
     "The requested file is not available." : "Eskatutako fitxategia ez dago eskuragarri.",
     "The requested files are not available." : "Eskatutako fitxategiak ez daude eskuragarri.",
-    "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
-    "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "Destination is not a folder" : "Helburua ez da karpeta bat",
     "This file/folder is already in that directory" : "Fitxategi/karpeta hau dagoeneko karpeta horretan dago",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Ezin duzu fitxategi/karpeta bat berera edo bere azpikarpeta batera mugitu",
@@ -485,6 +476,8 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Erabili helbide hau WebDAV bidez zure fitxategietara sartzeko",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FA gaitu baduzu, aplikazioaren pasahitz berria sortu eta erabili behar duzu hemen klik eginez.",
     "Deletion cancelled" : "Ezabatzea bertan behera utzi da",
+    "Moving \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
+    "Copying \"{source}\" to \"{destination}\" …" : "«{source}» «{destination}»(e)ra mugitzen",
     "Move cancelled" : "Mugimendua bertan behera utzi da",
     "Cancelled move or copy of \"{filename}\"." : "\"{filename}\" -ren mugimendua edo kopia bertan behera utzi da.",
     "Cancelled move or copy operation" : "Mugitze edo kopiatze operazioa utzi da",
@@ -504,6 +497,7 @@ OC.L10N.register(
     "renamed file" : "fitxategia berrizendatu da",
     "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Windows-ekin bateragarriak diren fitxategi-izenak gaitu ondoren, lehendik dauden fitxategiak ezin dira gehiago aldatu, baina jabeak baliozko izen berria jar diezaieke.",
     "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Fitxategiak automatikoki migratu daitezke ezarpen hau gaitu ondoren. Kontsultatu occ komandoari buruzko dokumentazioa.",
+    "Submitting fields …" : "Bidaltzeko eremuak",
     "Filter file names …" : "Iragazi fitxategien izenak...",
     "Prevent warning dialogs from open or reenable them." : "Ohar-elkarrizketak ez irekitzea edo berriro aktibatzea.",
     "Show a warning dialog when changing a file extension." : "Erakutsi oharra fitxategi baten luzapena aldatzean",
@@ -522,6 +516,12 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Nabigatu ezkerreko fitxategira (sareta moduan)",
     "Navigate to the file on the right (in grid mode)" : "Nabigatu eskuineko fitxategira (sareta moduan)",
     "Toggle the grid view" : "Txandakatu sareta ikuspegia",
-    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako"
+    "Open the sidebar for a file" : "Ireki alboko barra fitxategi baterako",
+    "Save as …" : "Gorde honela...",
+    "Converting files …" : "Fitxategiak bihurtzen...",
+    "Converting file …" : "Fitxategia bihurtzen...",
+    "Search everywhere …" : "Bilatu nonahi...",
+    "Search here …" : "Bilatu hemen...",
+    "Preparing …" : "Prestatzen..."
 },
 "nplurals=2; plural=(n != 1);");
