@@ -1,13 +1,6 @@
 OC.L10N.register(
     "settings",
     {
-    "Private" : "Privat",
-    "Local" : "Local",
-    "Federated" : "Federated",
-    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
-    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
-    "Verify" : "Verificar",
-    "Verifying …" : "Verificacion…",
     "Unable to change password" : "Cambiament impossible del senhal",
     "Very weak password" : "Senhal plan feble",
     "Weak password" : "Senhal feble",
@@ -70,6 +63,8 @@ OC.L10N.register(
     "Background jobs" : "Prètzfaches de rèireplan",
     "Unlimited" : "Illimitat",
     "Verifying" : "Verificacion",
+    "Verifying …" : "Verificacion…",
+    "Verify" : "Verificar",
     "Disabled" : "Desactivat",
     "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
@@ -78,22 +73,29 @@ OC.L10N.register(
     "Architecture" : "Arquitectura",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vòstra basa de donada s’executa pas amb la transaccion de nivèl d’isolacion « READ COMMITTED ». Aquò pòt causar problèmas quand mantuna accion s’executan en parallèl.",
     "Nextcloud settings" : "Paramètres Nextcloud",
+    "Enable" : "Activar",
     "None" : "Pas cap",
-    "Set default expiration date for shares" : "Definir una data d’expiracion per defaut pels partatges",
     "Two-Factor Authentication" : "Autentificacion dos factors",
     "Limit to groups" : "Limitar als grops",
     "Save changes" : "Enregistrar las modificacions",
     "Update to {update}" : "Actualizar en {update}",
     "Remove" : "Suprimir",
-    "Disable" : "Desactivar",
+    "Disable all" : "Desactivar tot",
     "Name" : "Nom",
     "Version" : "Version",
     "Actions" : "Accions",
-    "Disable all" : "Desactivar tot",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicacion an una mesa a jorn de disponibla","%n aplicacions an una mesa a jorn de disponibla"],
+    "Group name" : "Nom del grop",
     "Loading" : "Cargament",
+    "Type" : "Tipe",
+    "Confirm" : "Confirmar",
+    "Cancel" : "Anullar",
     "Description" : "Descripcion",
-    "Details" : "Detalhs",
+    "View in store" : "Veire a la botiga",
+    "Visit website" : "Veire lo site web",
+    "Admin documentation" : "Documentacion admin",
+    "Developer documentation" : "Documentacion desvolopaire",
+    "Details" : "Per lo Menut",
     "All" : "Tot",
     "No results" : "Cap de resultat",
     "Update to {version}" : "Metre a jorn cap a {version}",
@@ -102,22 +104,18 @@ OC.L10N.register(
     "Report a bug" : "Raportar un bug",
     "Request feature" : "Demanda de foncionalitat",
     "Ask questions or discuss" : "Pausar de question o discutir",
-    "View in store" : "Veire a la botiga",
-    "Visit website" : "Veire lo site web",
-    "Admin documentation" : "Documentacion d’admin",
-    "Developer documentation" : "Documentacion desvolopaire",
     "Changelog" : "Nòta de version",
-    "Device settings" : "Paramètres periferic",
-    "Allow filesystem access" : "Permetre accès filesystem",
-    "Rename" : "Renomenar",
-    "Revoke" : "Revocar",
-    "Wipe device" : "Tirar periferic",
     "Google Chrome for Android" : "Google Chrome per Android",
     "{productName} iOS app" : "Aplicacion iOS {productName}",
     "{productName} Android app" : "Aplicacion Android {productName}",
     "{productName} Talk for iOS" : "Talk de {productName} per iOS",
     "{productName} Talk for Android" : "Talk de {productName} per Android",
     "This session" : "Aquesta session",
+    "Device settings" : "Paramètres periferic",
+    "Allow filesystem access" : "Permetre accès filesystem",
+    "Rename" : "Tornar nommar",
+    "Revoke" : "Revocar",
+    "Wipe device" : "Tirar periferic",
     "Device" : "Periferic",
     "Last activity" : "Darrièra activitat",
     "Devices & sessions" : "Periferics e sessions",
@@ -125,32 +123,28 @@ OC.L10N.register(
     "Login" : "Login",
     "Password" : "Senhal",
     "Profile" : "Perfil",
-    "Enable" : "Activar",
-    "Cancel" : "Anullar",
-    "Confirm" : "Confirmar",
+    "Enable encryption" : "Activar lo chiframent",
     "Submit" : "Transmetre",
     "Rename group" : "Renomenar lo grop",
-    "Remove group" : "Suprimir lo grop",
     "Current password" : "Senhal actual",
     "New password" : "Senhal novèl",
-    "Change password" : "Cambiar de senhal",
     "Picture provided by original account" : "Imatge provesit pel compte d’origina",
-    "Your biography" : "Vòstra biografia",
     "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
     "Your full name" : "Vòstre nom complèt",
+    "No email address set" : "Cap d’adreça pas definida",
     "Email options" : "Opcions d’email",
     "This address is not confirmed" : "Aquesta adreça es pas confirmada",
     "Set as primary email" : "Definir coma adreça principala",
-    "No email address set" : "Cap d’adreça pas definida",
     "Your headline" : "Vòstre títol",
-    "Help translate" : "Ajudar a traduire",
-    "Unable to update language" : "Actualizacion de la lenga impossibla",
     "No language set" : "Cap de lenga pas definida",
+    "Unable to update language" : "Actualizacion de la lenga impossibla",
+    "Help translate" : "Ajudar a traduire",
+    "Week starts on {firstDayOfWeek}" : "La setmana comença lo {firstDayOfWeek}",
     "Your organisation" : "Vòstra organizacion",
     "Your phone number" : "Vòstre numèro de telefòn",
     "Edit your Profile visibility" : "Modificatz la visibilitat de vòstre perfil",
     "Your role" : "Vòstre ròtle",
-    "Add" : "Ajustar",
+    "Add" : "Apondre",
     "Create" : "Crear",
     "Change" : "Modificar",
     "Delete" : "Suprimir",
@@ -158,7 +152,6 @@ OC.L10N.register(
     "Default language" : "Lenga per defaut",
     "Common languages" : "Lengas comunas",
     "Other languages" : "Autras lengas",
-    "Display name" : "Nom afichat",
     "Email" : "Adreça corrièl",
     "Quota" : "Quota",
     "Language" : "Lenga",
@@ -169,19 +162,17 @@ OC.L10N.register(
     "Account deletion" : "Supression de compte",
     "Delete {userid}'s account" : "Suprimir lo compte de {userid}",
     "Welcome mail sent!" : "Email de benvenguda enviat !",
-    "Done" : "Done",
     "Edit" : "Modificar",
     "Visibility" : "Visibilitat",
     "Show last login" : "Afichar la darrièra connexion",
     "Send email" : "Enviar email",
     "Default quota" : "Quota per defaut",
-    "Adding your device …" : "Apondon del periferic…",
     "Unnamed device" : "Periferic sens nom",
     "Passwordless Authentication" : "Autentificacion sens senhal",
     "No devices configured." : "Cap de periferic pas configurat.",
     "Your browser does not support WebAuthn." : "Vòstre navigador es pas compatible amb WebAuthn.",
+    "Apply" : "Aplicar",
     "Admins" : "Admins",
-    "Group name" : "Nom del grop",
     "Sending…" : "Mandadís…",
     "Email sent" : "Corrièl mandat",
     "Location" : "Emplaçament",
@@ -196,12 +187,19 @@ OC.L10N.register(
     "Website" : "Site web",
     "Profile visibility" : "Visibilitat perfil",
     "Locale" : "Varianta lingüistica",
+    "Private" : "Privat",
+    "Local" : "Local",
+    "Federated" : "Federated",
+    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
+    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
     "Your apps" : "Vòstras aplicacions",
     "Active apps" : "Aplicacions activas",
     "Disabled apps" : "Aplicacions desactivadas",
     "Updates" : "Mesas a jorn",
     "Show to everyone" : "Afichar a tot lo monde",
     "Hide" : "Amagar",
+    "Disable" : "Desactivar",
+    "Unknown" : "Desconegut",
     "Never" : "Pas jamais",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Error" : "Error",
@@ -218,50 +216,12 @@ OC.L10N.register(
     "Save" : "Salvar",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Aimar nòstra pagina Facebook",
-    "Follow us on Twitter" : "Nos seguir sus Twitter",
     "Follow us on Mastodon" : "Nos seguir sus Mastodon",
     "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
     "Subscribe to our newsletter" : "S’abonar a l’infoletra",
-    "Invalid user" : "Utilizaire invalid",
-    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
-    "Enable all" : "Activar tot",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Username" : "Nom d'utilizaire",
-    "Copied!" : "Copiat !",
-    "Copy" : "Copiar",
-    "Your email address" : "Vòstra adreça electronica",
-    "Additional emails" : "Emails suplementaris",
-    "Enable Profile" : "Activar Perfil",
-    "Add new password" : "Apondre senhal novèl",
-    "Add new email address" : "Apondre adreça electronica",
-    "Add user to group" : "Apondre utilizaire al grop",
-    "Set user as admin for" : "Definir l’utilizaire coma admin per",
-    "Select user quota" : "Seleccionar lo quota utilizaire",
-    "Delete user" : "Suprimir l’utilizaire",
-    "Wipe all devices" : "Escafar totes los periferics",
-    "Disable user" : "Desactivar l’utilizaire",
-    "Enable user" : "Activar l’utilizaire",
-    "Edit User" : "Modificar l’utilizaire",
-    "New user" : "Utilizaire novèl",
-    "Add a new user" : "Apondre un utilizaire novè",
-    "No users in here" : "Cap d’utilizaire aquí",
-    "Name your device" : "Nommatz vòstre periferic",
-    "by {author}\n{license}" : "per {author}\n{license}",
-    "Enter group name" : "Picatz un nom de grop",
-    "Add group" : "Apondre grop",
-    "Active users" : "Utilizaires actius",
-    "Disabled users" : "Utilizaires desactivats",
-    "Show Languages" : "Veire las lengas",
-    "Not saved" : "Pas enregistrat",
-    "Twitter" : "Twitter",
-    "SMTP Username" : "Utilizaire SMTP",
-    "day(s)" : "jorn(s)",
-    "Set default expiration date" : "Definir una data d’expiracion per defaut"
+    "Set default expiration date for shares" : "Definir una data d’expiracion per defaut pels partatges",
+    "Your biography" : "Vòstra biografia",
+    "You are using <strong>{usage}</strong>" : "Utilizatz <strong>{usage}</strong>",
+    "Adding your device …" : "Apondon del periferic…"
 },
 "nplurals=2; plural=(n > 1);");
