@@ -45,17 +45,6 @@ OC.L10N.register(
     "Collaborative tags" : "Etichette collaborative",
     "Collaborative tagging functionality which shares tags among people." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone.",
     "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra le persone. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
-    "Create or edit tags" : "Crea o modifica etichette",
-    "Search for a tag to edit" : "Cerca un'etichetta da modificare",
-    "Collaborative tags …" : "Etichette collaborative …",
-    "No tags to select" : "Nessuna etichetta da selezionare",
-    "Tag name" : "Nome etichetta",
-    "Tag level" : "Livello etichetta",
-    "Create" : "Crea",
-    "Update" : "Aggiorna",
-    "Delete" : "Elimina",
-    "Reset" : "Ripristina",
-    "Loading …" : "Caricamento…",
     "Public" : "Pubblico",
     "Restricted" : "Limitato",
     "Invisible" : "invisibile",
@@ -65,33 +54,48 @@ OC.L10N.register(
     "Failed to update tag" : "Aggiornamento dell'etichetta fallito",
     "Deleted tag" : "Etichetta eliminata",
     "Failed to delete tag" : "Eliminazione etichetta fallita",
+    "Create or edit tags" : "Crea o modifica etichette",
+    "Search for a tag to edit" : "Cerca un'etichetta da modificare",
+    "No tags to select" : "Nessuna etichetta da selezionare",
+    "Tag name" : "Nome etichetta",
+    "Tag level" : "Livello etichetta",
+    "Create" : "Crea",
+    "Update" : "Aggiorna",
+    "Delete" : "Elimina",
+    "Reset" : "Ripristina",
+    "Loading …" : "Caricamento in corso...",
+    "{displayName} (hidden)" : "{displayName} (nascosto)",
+    "{displayName} (restricted)" : "{displayName} (limitato)",
+    "Failed to apply tags changes" : "Impossibile applicare le modifiche ai tag",
     "Manage tags" : "Gestisci etichette",
-    "No tags found" : "Nessuna etichetta trovata",
+    "Applying tags changes…" : "Applico le modifiche ai tag...",
+    "Search or create tag" : "Cerca o crea tag",
+    "Create new tag" : "Crea un nuovo tag",
     "Cancel" : "Annulla",
-    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
+    "Apply" : "Applica",
+    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
+    "Failed to load tags" : "Caricamento etichette non riuscito",
+    "Failed to select tag" : "Selezione etichetta fallita",
     "Search or create collaborative tags" : "Cerca o crea etichette collaborative",
     "No tags to select, type to create a new tag" : "Nessuna etichetta da selezionare, digita per crearne una nuova",
-    "Failed to load tags" : "Caricamento etichette non riuscito",
-    "Failed to load selected tags" : "Caricamento etichette selezionate fallito",
-    "Failed to select tag" : "Selezione etichetta fallita",
     "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Le etichette collaborative sono disponibili per tutti gli utenti. Le etichette limitate sono visibili agli utenti, ma non possono essere assegnate da essi. Le etichette invisibili sono per uso interno, poiché gli utenti non possono vederle o assegnarle.",
     "Assigned collaborative tags" : "Etichette collaborative assegnate",
     "Open in Files" : "Apri in File",
     "List of tags and their associated files and folders." : "Lista di etichette e dei loro file e cartelle associati.",
+    "No tags found" : "Nessuna etichetta trovata",
     "Tags you have created will show up here." : "Le etichette che hai creato saranno mostrate qui.",
+    "Failed to load tag" : "Impossibile caricare i tag",
     "Failed to load last used tags" : "Caricamento ultime etichette usate fallito",
     "Missing \"Content-Location\" header" : "Intestazione \"Content-Location\" mancante",
+    "A tag with the same name already exists" : "Esiste già un tag con lo stesso nome",
     "Failed to load tags for file" : "Caricamento delle etichette per il file fallito",
     "Failed to set tag for file" : "Impostazione dell'etichetta per il file fallita",
     "Failed to delete tag for file" : "Eliminazione dell'etichetta per il file fallita",
-    "Collaborative tagging functionality which shares tags among users." : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funzionalità di etichettatura collaborativa che condivide le etichette tra gli utenti. Ottima per le squadre.\n\t(Se sei un fornitore con un'installazione multi-tenant, ti consigliamo di disattivare questa applicazione poiché le etichette sono condivise.)",
-    "This file has the tag {tag}" : "Questo file ha l'etichetta {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "Il file ha le etichette {firstTags} e {lastTag}",
-    "No files in here" : "Qui non c'è alcun file",
-    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
-    "Name" : "Nome",
-    "Size" : "Dimensione",
-    "Modified" : "Modificato"
+    "Collaborative tags …" : "Etichette collaborative …",
+    "Loading …" : "Caricamento…",
+    "Loading collaborative tags …" : "Caricamento etichette collaborative …",
+    "File tags modification canceled" : "Modifiche ai tag dei file annullate",
+    "Select or create tags to apply to all selected files" : "Seleziona o crea i tag da applicare a tutti i file selezionati",
+    "Apply changes" : "Applica modifiche"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
