@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Unbekannter Dateityp",
     "An error occurred. Please contact your admin." : "Es ist ein Fehler aufgetreten. Bitte kontaktiere deine Administration.",
     "Invalid image" : "Ungültiges Bild",
-    "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuche es noch einmal",
-    "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
-    "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
-    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "State token does not match" : "Status-Token stimmen nicht überein",
     "Invalid app password" : "Ungültiges App-Passwort",
     "Could not complete login" : "Anmeldung konnte nicht abgeschlossen werden",
     "State token missing" : "Zustandstoken fehlt",
     "Your login token is invalid or has expired" : "Dein Anmelde-Token ist ungültig oder abgelaufen",
+    "Please use original client" : "Bitte den Original-Client verwenden",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Diese Community-Version von Nextcloud wird nicht unterstützt und (Push-)Benachrichtigungen sind nur begrenzt verfügbar.",
     "Login" : "Anmelden",
     "Unsupported email length (>255)" : "Nicht unterstützte E-Mail-Adresslänge (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Aufgabe nicht gefunden",
     "Internal error" : "Interner Fehler",
     "Not found" : "Nicht gefunden",
+    "Node is locked" : "Knoten ist gesperrt",
     "Bad request" : "Fehlerhafte Anfrage",
     "Requested task type does not exist" : "Angeforderter Aufgabentyp existiert nicht",
     "Necessary language model provider is not available" : "Erforderlicher Sprachmodellanbieter ist nicht verfügbar",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Kein Übersetzungsanbieter verfügbar",
     "Could not detect language" : "Sprache konnte nicht erkannt werden",
     "Unable to translate" : "Kann nicht übersetzt werden",
+    "No valid filters provided" : "Keine gültigen Filter angegeben",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Reparaturschritt:",
+    "Repair info:" : "Reparaturinformation:",
+    "Repair warning:" : "Reparaturwarnung:",
+    "Repair error:" : "Reparaturfehler:",
     "Nextcloud Server" : "Nextcloud-Server",
     "Some of your link shares have been removed" : "Einige der geteilten Freigaben wurden entfernt",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Aufgrund eines Sicherheitsfehlers mussten einige der geteilten Freigaben entfernt werden. Weitere Informationen im Link.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Gib deinen Abonnementschlüssel in der Support-App ein, um das Konto-Limit zu erhöhen. Damit erhältst du auch alle zusätzlichen Vorteile, die Nextcloud Enterprise bietet. Dies ist für den Betrieb in Unternehmen sehr zu empfehlen.",
     "Learn more ↗" : "Erfahre mehr ↗",
     "Preparing update" : "Update vorbereiten",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Reparaturschritt:",
-    "Repair info:" : "Reparaturinformation:",
-    "Repair warning:" : "Reparaturwarnung:",
-    "Repair error:" : "Reparaturfehler:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Bitte den Kommandozeilen-Updater verwenden, die Browser-Aktualisierung ist in der config.php deaktiviert.",
     "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
     "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (inkompatibel)",
     "The following apps have been disabled: %s" : "Folgende Apps wurden deaktiviert: %s",
     "Already up to date" : "Bereits aktuell",
-    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
-    "unknown text" : "Unbekannter Text",
-    "Hello world!" : "Hallo Welt!",
-    "sunny" : "sonnig",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
-    "new" : "Neu",
-    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
+    "Windows Command Script" : "Windows-Befehlsskript",
+    "Electronic book document" : "E-Book-Dokument",
+    "TrueType Font Collection" : "TrueType-Schriftartensammlung",
+    "Web Open Font Format" : "Web Open Font Format",
+    "GPX geographic data" : "GPX-Geodaten",
+    "Gzip archive" : "Gzip-Archiv",
+    "Adobe Illustrator document" : "Adobe Illustrator-Dokument",
+    "Java source code" : "Java Quellcode",
+    "JavaScript source code" : "JavaScript Quellcode",
+    "JSON document" : "JSON-Dokument",
+    "Microsoft Access database" : "Microsoft Access-Datenbank",
+    "Microsoft OneNote document" : "Microsoft OneNote-Dokument",
+    "Microsoft Word document" : "Microsoft Word-Dokument",
+    "Unknown" : "Unbekannt",
+    "PDF document" : "PDF-Dokument",
+    "PostScript document" : "PostScript-Dokument",
+    "RSS summary" : "RSS-Zusammenfassung",
+    "Android package" : "Android-Paket",
+    "KML geographic data" : "KML-Geodaten",
+    "KML geographic compressed data" : "Komprimierte KML-Geodaten",
+    "Lotus Word Pro document" : "Lotus Word Pro-Dokument",
+    "Excel spreadsheet" : "Excel-Tabelle",
+    "Excel add-in" : "Excel-Add-in",
+    "Excel 2007 binary spreadsheet" : "Excel 2007 Binärtabelle",
+    "Excel spreadsheet template" : "Excel-Tabellenvorlage",
+    "Outlook Message" : "Outlook-Nachricht",
+    "PowerPoint presentation" : "PowerPoint-Präsentation",
+    "PowerPoint add-in" : "PowerPoint Add-in",
+    "PowerPoint presentation template" : "PowerPoint-Präsentationsvorlage",
+    "Word document" : "Word Dokument",
+    "ODF formula" : "ODF-Formel",
+    "ODG drawing" : "ODG-Zeichnung",
+    "ODG drawing (Flat XML)" : "ODG-Zeichnung (Flat XML)",
+    "ODG template" : "ODG-Vorlage",
+    "ODP presentation" : "ODP-Präsentation",
+    "ODP presentation (Flat XML)" : "ODP-Präsentation (Flat XML)",
+    "ODP template" : "ODP-Vorlage",
+    "ODS spreadsheet" : "ODS-Tabelle",
+    "ODS spreadsheet (Flat XML)" : "ODS-Tabelle (Flat XML)",
+    "ODS template" : "ODS-Vorlage",
+    "ODT document" : "ODT-Dokument",
+    "ODT document (Flat XML)" : "ODT-Dokument (Flat XML)",
+    "ODT template" : "ODT-Vorlage",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007-Präsentation",
+    "PowerPoint 2007 show" : "PowerPoint 2007-Schau",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007-Präsentationsvorlage",
+    "Excel 2007 spreadsheet" : "Excel 2007-Tabelle",
+    "Excel 2007 spreadsheet template" : "Excel 2007-Tabellenvorlage",
+    "Word 2007 document" : "Word 2007-Dokument",
+    "Word 2007 document template" : "Word 2007-Dokumentenvorlage",
+    "Microsoft Visio document" : "Microsoft Visio-Dokument",
+    "WordPerfect document" : "WordPerfect-Dokument",
+    "7-zip archive" : "7-zip-Archiv",
+    "Blender scene" : "Blender-Szene",
+    "Bzip2 archive" : "Bzip2-Archiv",
+    "Debian package" : "Debian-Paket",
+    "FictionBook document" : "FictionBook-Dokument",
+    "Unknown font" : "Unbekannte Schriftart",
+    "Krita document" : "Krita-Dokument",
+    "Mobipocket e-book" : "Mobipocket E-Book",
+    "Windows Installer package" : "Windows-Installationspaket",
+    "Perl script" : "Perl-Skript",
+    "PHP script" : "PHP-Skript",
+    "Tar archive" : "Tar-Archiv",
+    "XML document" : "XML-Dokument",
+    "YAML document" : "YAML-Dokument",
+    "Zip archive" : "Zip-Archiv",
+    "Zstandard archive" : "Zstandard-Archiv",
+    "AAC audio" : "AAC-Audio",
+    "FLAC audio" : "FLAC-Audio",
+    "MPEG-4 audio" : "MPEG-4-Audio",
+    "MP3 audio" : "MP3-Audio",
+    "Ogg audio" : "Ogg-Audio",
+    "RIFF/WAVe standard Audio" : "RIFF/WAVe Standard-Audio",
+    "WebM audio" : "WebM-Audio",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast-Wiedergabeliste",
+    "Windows BMP image" : "Windows BMP-Bild",
+    "Better Portable Graphics image" : "Better Portable Graphics-Bild",
+    "EMF image" : "EMF-Bild",
+    "GIF image" : "GIF-Bild",
+    "HEIC image" : "HEIC-Bild",
+    "HEIF image" : "HEIF-Bild",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2-Bild",
+    "JPEG image" : "JPEG-Bild",
+    "PNG image" : "PNG-Bild",
+    "SVG image" : "SVG-Bild",
+    "Truevision Targa image" : "Truevision Targa-Bild",
+    "TIFF image" : "TIFF-Bild",
+    "WebP image" : "WebP-Bild",
+    "Digital raw image" : "Digitales raw-Bild",
+    "Windows Icon" : "Windows-Symbol",
+    "Email message" : "E-Mail-Nachricht",
+    "VCS/ICS calendar" : "VCS/ICS-Kalender",
+    "CSS stylesheet" : "CSS-Stylesheet",
+    "CSV document" : "CSV-Dokument",
+    "HTML document" : "HTML-Dokument",
+    "Markdown document" : "Markdown-Dokument",
+    "Org-mode file" : "Org-mode-Datei",
+    "Plain text document" : "Rohtext-Dokument",
+    "Rich Text document" : "Rich Text-Dokument",
+    "Electronic business card" : "Elektronische Visitenkarte",
+    "C++ source code" : "C++-Quellcode",
+    "LDIF address book" : "LDIF-Adressbuch",
+    "NFO document" : "NFO-Dokument",
+    "PHP source" : "PHP-Quelltext",
+    "Python script" : "Python-Skript",
+    "ReStructuredText document" : "ReStructuredText-Dokument",
+    "3GPP multimedia file" : "3GPP Multimedia-Datei",
+    "MPEG video" : "MPEG-Video",
+    "DV video" : "DV-Video",
+    "MPEG-2 transport stream" : "MPEG-2-Transportstrom",
+    "MPEG-4 video" : "MPEG-4-Video",
+    "Ogg video" : "Ogg-Video",
+    "QuickTime video" : "QuickTime-Video",
+    "WebM video" : "WebM-Video",
+    "Flash video" : "Flash-Video",
+    "Matroska video" : "Matroska-Video",
+    "Windows Media video" : "Windows Media-Video",
+    "AVI video" : "AVI-Video",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
     "Update to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Es ist ein Fehler aufgetreten.",
@@ -105,11 +213,11 @@ OC.L10N.register(
     "Yes" : "Ja",
     "The remote URL must include the user." : "Die entfernte URL muss den Benutzer enthalten.",
     "Invalid remote URL." : "Ungültige entfernte URL.",
-    "Failed to add the public link to your Nextcloud" : "Fehler beim Hinzufügen des öffentlichen Links zur Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Der öffentliche Link konnte nicht zu deiner Nextcloud hinzugefügt werden",
     "Federated user" : "Federated Benutzer",
     "user@your-nextcloud.org" : "benutzer@deine-nextcloud.org",
     "Create share" : "Freigabe erstellen",
-    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
+    "Direct link copied" : "Direktlink kopiert",
     "Please copy the link manually:" : "Bitte den Link manuell kopieren:",
     "Custom date range" : "Benutzerdefinierter Zeitbereich",
     "Pick start date" : "Startdatum wählen",
@@ -118,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "In aktueller App suchen ",
     "Clear search" : "Suche löschen",
     "Search everywhere" : "Überall suchen",
-    "Searching …" : "Suche …",
+    "Searching …" : "Suche …",
     "Start typing to search" : "Beginne mit der Eingabe, um zu suchen",
+    "Minimum search length is {minSearchLength} characters" : "Die Mindestsuchlänge beträgt {minSearchLength} Zeichen",
     "No matching results" : "Keine passenden Suchergebnisse",
     "Today" : "Heute",
     "Last 7 days" : "Die letzten 7 Tage",
     "Last 30 days" : "Die letzten 30 Tage",
     "This year" : "Dieses Jahr",
     "Last year" : "Letztes Jahr",
+    "Between {startDate} and {endDate}" : "Von {startDate} bis {endDate}",
     "Unified search" : "Einheitliche Suche",
     "Search apps, files, tags, messages" : "Nach Apps, Dateien, Schlagworten und Nachrichten suchen",
     "Places" : "Orte",
@@ -133,26 +243,27 @@ OC.L10N.register(
     "Search people" : "Personen suchen",
     "People" : "Personen",
     "Filter in current view" : "Filter in aktueller Ansicht",
+    "Search connected services" : "Verbundene Dienste durchsuchen",
     "Results" : "Ergebnisse",
     "Load more results" : "Weitere Ergebnisse laden",
     "Search in" : "Suche in",
     "Log in" : "Anmelden",
-    "Logging in …" : "Melde an …",
+    "Logging in …" : "Melde an …",
     "Log in to {productName}" : "Anmelden bei {productName}",
-    "Wrong login or password." : "Anmeldename oder Passwort falsch",
+    "Wrong login or password." : "Kontoname oder Passwort falsch",
     "This account is disabled" : "Dieses Konto ist deaktiviert",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Es wurden mehrere ungültige Anmeldeversuche von deiner IP-Adresse festgestellt. Daher wird die nächste Anmeldung um 30 Sekunden verzögert.",
-    "Account name or email" : "Kontoname oder E-Mail",
+    "Account name or email" : "Kontoname oder E-Mail-Adresse",
     "Account name" : "Name des Kontos",
     "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
     "Please contact your administrator." : "Bitte kontaktiere die Administration.",
-    "Temporary error" : "Vorübergehender Fehler",
-    "Please try again." : "Bitte erneut versuchen.",
+    "Session error" : "Sitzungsfehler",
+    "It appears your session token has expired, please refresh the page and try again." : "Der Sitzungstoken scheint abgelaufen zu sein. Bitte diese Seite aktualisieren und neu versuchen.",
     "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere die Administration.",
     "Password" : "Passwort",
     "Log in with a device" : "Mit einem Gerät anmelden",
-    "Login or email" : "Anmeldename oder E-Mail-Adresse",
+    "Login or email" : "Kontoname oder E-Mail-Adresse",
     "Your account is not setup for passwordless login." : "Dein Konto ist nicht für eine Anmeldung ohne Passwort eingerichtet.",
     "Your connection is not secure" : "Deine Verbindung ist nicht sicher",
     "Passwordless authentication is only available over a secure connection." : "Anmeldung ohne Passwort ist nur über eine sichere Verbindung möglich",
@@ -174,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Gemeinsame Dokumente, Tabellenkalkulationen und Präsentationen, die auf Collabora Online basieren.",
     "Distraction free note taking app." : "Ablenkungsfreie Notizen-App",
     "Recommended apps" : "Empfohlene Apps",
-    "Loading apps …" : "Lade Apps …",
+    "Loading apps …" : "Lade Apps …",
     "Could not fetch list of apps from the App Store." : "Liste der Apps konnte nicht vom App-Store abgerufen werden",
     "App download or installation failed" : "Herunterladen oder Installieren der App fehlgeschlagen",
     "Cannot install this app because it is not compatible" : "App kann nicht installiert werden, da sie inkompatibel ist",
     "Cannot install this app" : "App kann nicht installiert werden",
     "Skip" : "Überspringen",
-    "Installing apps …" : "Installiere Apps …",
+    "Installing apps …" : "Installiere Apps …",
     "Install recommended apps" : "Empfohlene Apps installieren",
     "Avatar of {displayName}" : "Avatar von {displayName}",
     "Settings menu" : "Einstellungen-Menü",
-    "Loading your contacts …" : "Lade deine Kontakte …",
-    "Looking for {term} …" : "Suche nach {term} …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
     "Search contacts" : "Kontakte suchen",
     "Reset search" : "Suche zurücksetzen",
-    "Search contacts …" : "Kontakte suchen …",
+    "Search contacts …" : "Kontakte suchen …",
     "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
     "No contacts found" : "Keine Kontakte gefunden",
     "Show all contacts" : "Alle Kontakte anzeigen",
@@ -200,13 +311,18 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Es ist ein Fehler beim Suchen nach {type} aufgetreten",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Die Suche beginnt, sobald du mit der Eingabe beginnst. Die Suchergebnisse kannst du mit den Pfeiltasten auswählen,",
     "Search for {name} only" : "Nur nach {name} suchen",
-    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
     "Forgot password?" : "Passwort vergessen?",
     "Back to login form" : "Zurück zum Anmeldeformular",
     "Back" : "Zurück",
     "Login form is disabled." : "Das Anmeldeformular ist deaktiviert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Das Nextcloud-Anmeldeformular ist deaktiviert. Nutze ggf. eine andere Anmeldemöglichkeit oder wende dich an deine Administration.",
     "More actions" : "Weitere Aktionen",
+    "User menu" : "Benutzermenü",
+    "Your guest name: {user}" : "Dein Gastname: {user}",
+    "You are currently not identified." : "Du bist derzeit nicht identifiziert.",
+    "Set public name" : "Öffentlichen Namen festlegen",
+    "Change public name" : "Öffentlichen Namen ändern",
     "Password is too weak" : "Passwort ist zu schwach",
     "Password is weak" : "Passwort ist schwach",
     "Password is average" : "Passwort ist durchschnittlich",
@@ -239,7 +355,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z. B. localhost:5432)",
     "Database host" : "Datenbank-Host",
     "localhost" : "localhost",
-    "Installing …" : "Installiere …",
+    "Installing …" : "Installiere …",
     "Install" : "Installieren",
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schau in die Dokumentation",
@@ -248,7 +364,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
     "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
     "Supported versions" : "Unterstützte Versionen",
-    "Search {types} …" : "Suche {types} …",
+    "Search {types} …" : "Suche {types} …",
     "Choose {file}" : "{file} auswählen",
     "Choose" : "Auswählen",
     "Copy to {target}" : "Nach {target} kopieren",
@@ -268,7 +384,7 @@ OC.L10N.register(
     "(all selected)" : "(Alle ausgewählt)",
     "({count} selected)" : "({count} ausgewählt)",
     "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
-    "Saving …" : "Speichern …",
+    "Saving …" : "Speichere …",
     "seconds ago" : "Gerade eben",
     "Connection to server lost" : "Verbindung zum Server verloren",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
@@ -276,33 +392,25 @@ OC.L10N.register(
     "Show details" : "Details anzeigen",
     "Hide details" : "Details ausblenden",
     "Rename project" : "Projekt umbenennen",
-    "Failed to rename the project" : "Konnte Projekt nicht umbenennen",
-    "Failed to create a project" : "Konnte Projekt nicht erstellen",
+    "Failed to rename the project" : "Projekt konnte nicht umbenannt werden",
+    "Failed to create a project" : "Projekt konnte nicht erstellt werden",
     "Failed to add the item to the project" : "Eintrag konnte nicht zum Projekt hinzu gefügt werden",
     "Connect items to a project to make them easier to find" : "Zum leichten Auffinden von Einträgen, diese zu einem Projekt hinzufügen",
     "Type to search for existing projects" : "Nach existierenden Projekten suchen",
     "New in" : "Neu in",
     "View changelog" : "Liste der Veränderungen ansehen",
-    "No action available" : "Keine Aktion verfügbar",
-    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
     "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
-    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
-    "Restricted" : "Eingeschränkt",
-    "Invisible" : "Unsichtbar",
-    "Delete" : "Löschen",
-    "Rename" : "Umbenennen",
-    "Collaborative tags" : "Kollaborative Tags",
-    "No tags found" : "Keine Tags gefunden",
     "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
     "Personal" : "Persönlich",
     "Accounts" : "Konten",
     "Admin" : "Administration",
     "Help" : "Hilfe",
     "Access forbidden" : "Zugriff verboten",
+    "You are not allowed to access this page." : "Du darfst diese Seite nicht aufrufen.",
+    "Back to %s" : "Zurück zu %s",
     "Page not found" : "Seite nicht gefunden",
     "The page could not be found on the server or you may not be allowed to view it." : "Die Seite konnte auf dem Server nicht gefunden werden oder du bist nicht berechtigt sie anzusehen.",
-    "Back to %s" : "Zurück zu %s",
     "Too many requests" : "Zu viele Anfragen",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zu viele Anfragen aus deinem Netzwerk. Versuche es später erneut oder wende dich an deine Administration, wenn dies ein Fehler sein sollte.",
     "Error" : "Fehler",
@@ -321,7 +429,7 @@ OC.L10N.register(
     "Line: %s" : "Zeile: %s",
     "Trace" : "Trace",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Es sieht so aus, als ob du Nextcloud erneut installieren möchtest. Es fehlt jedoch die Datei CAN_INSTALL in deinem Konfigurationsordner. Bitte erstelle die Datei CAN_INSTALL im Konfigurationsordner um fortzufahren.",
-    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL konnte nicht aus dem Konfigurationsordner gelöscht werden. Bitte entferne die Datei manuell.",
+    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL konnte nicht aus dem Konfigurationsordner entfernt werden. Bitte entferne die Datei manuell.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt JavaScript zum ordnungsgemäßen Betrieb. Bitte {linkstart}aktiviere JavaScript{linkend} und lade die Seite neu.",
     "Skip to main content" : "Zum Hauptinhalt springen",
     "Skip to navigation of app" : "Zum Navigationsbereich der App springen",
@@ -346,8 +454,8 @@ OC.L10N.register(
     "Email address" : "E-Mail-Adresse",
     "Password sent!" : "Passwort wurde verschickt",
     "You are not authorized to request a password for this share" : "Du bist nicht berechtigt, für diese Freigabe ein Passwort anzufordern",
-    "Two-factor authentication" : "Zwei-Faktor Authentifizierung",
-    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte wähle einem zweiten Faktor für die Authentifizierung:",
+    "Two-factor authentication" : "Zwei-Faktor-Authentifizierung",
+    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte wähle einen zweiten Faktor für die Authentifizierung:",
     "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Mindestens eine deiner Zwei-Faktor-Authentifizierungsmethoden konnte nicht geladen werden. Kontaktiere deine Administration.",
     "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Die Zwei-Faktor-Authentifizierung wird erzwungen, wurde jedoch für dein Konto nicht konfiguriert. Wende dich für Unterstützung an deine Administration.",
     "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Die Zwei-Faktor-Authentifizierung wird erzwungen, wurde jedoch für dein Konto nicht konfiguriert. Bitte fahre mit der Einrichtung der Zwei-Faktor-Authentifizierung fort.",
@@ -376,23 +484,48 @@ OC.L10N.register(
     "Upgrade via web on my own risk" : "Aktualisierung über die Web-Oberfläche auf eigenes Risiko",
     "Maintenance mode" : "Wartungsmodus",
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
-    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald die Nextcloud-Instanz wieder verfügbar ist.",
+    "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere die Systemadministration, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
-    "Currently open" : "Derzeit geöffnet",
-    "Login with username or email" : "Kontoname oder E-Mail",
-    "Login with username" : "Anmeldung mit Benutzernamen",
+    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
+    "unknown text" : "Unbekannter Text",
+    "Hello world!" : "Hallo Welt!",
+    "sunny" : "sonnig",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
+    "new" : "Neu",
+    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
+    "Searching …" : "Suche …",
+    "Logging in …" : "Melde an…",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, Videoanrufe, Bildschirmfreigaben, Online-Besprechungen und Webkonferenzen - in deinem Browser sowie mit mobilen Apps.",
+    "Loading apps …" : "Lade Apps …",
+    "Installing apps …" : "Installiere Apps …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
+    "Search contacts …" : "Kontakte suchen …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
     "You have not added any info yet" : "Du hast noch keine Infos hinzugefügt",
     "{user} has not added any info yet" : "{user} hat noch keine Infos hinzugefügt",
     "Error opening the user status modal, try hard refreshing the page" : "Fehler beim Modal-öffnen des Benutzerstatus, versuche die Seite zu aktualisieren",
     "Edit Profile" : "Profil bearbeiten",
     "The headline and about sections will show up here" : "Die Überschrift und der Infobereich werden hier angezeigt",
-    "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
+    "Search {types} …" : "Suche {types} …",
+    "Saving …" : "Speichern …",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
+    "No action available" : "Keine Aktion verfügbar",
+    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
+    "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
+    "Restricted" : "Eingeschränkt",
+    "Invisible" : "Unsichtbar",
+    "Delete" : "Löschen",
+    "Rename" : "Umbenennen",
+    "Collaborative tags" : "Kollaborative Schlagworte",
+    "No tags found" : "Keine Tags gefunden",
     "Profile not found" : "Profil nicht gefunden",
     "The profile does not exist." : "Das Profil existiert nicht",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
@@ -404,6 +537,8 @@ OC.L10N.register(
     "Toggle password visibility" : "Passwortsichtbarkeit umschalten",
     "Configure the database" : "Datenbank einrichten",
     "Only %s is available." : "Es ist nur %s verfügbar.",
-    "Database account" : "Datenbankkonto"
+    "Database account" : "Datenbankkonto",
+    "Installing …" : "Installiere …",
+    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert"
 },
 "nplurals=2; plural=(n != 1);");
