@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Άγνωστος τύπος αρχείου",
     "An error occurred. Please contact your admin." : "Προέκυψε σφάλμα. Παρακαλούμε επικοινωνήστε με τον διαχειριστή.",
     "Invalid image" : "Μη έγκυρη εικόνα",
-    "No temporary profile picture available, try again" : "Δεν υπάρχει προσωρινή φωτογραφία προφίλ, δοκιμάστε ξανά",
-    "No crop data provided" : "Δεν δόθηκαν δεδομένα περικοπής",
-    "No valid crop data provided" : "Έχουν δοθεί μη έγκυρα δεδομένα περικοπής",
-    "Crop is not square" : "Η περικοπή δεν έχει τετράγωνο σχήμα",
     "State token does not match" : "Το αναγνωριστικό κατάστασης δεν ταιριάζει",
     "Invalid app password" : "Λανθασμένο συνθηματικό εφαρμογής",
     "Could not complete login" : "Αδυναμία ολοκλήρωσης σύνδεσης",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Δεν υπάρχει διαθέσιμος πάροχος μεταφράσεων",
     "Could not detect language" : "Δεν ήταν δυνατός ο εντοπισμός της γλώσσας",
     "Unable to translate" : "Αδυναμία μετάφρασης",
+    "No valid filters provided" : "Δεν έχουν δοθεί έγκυρα φίλτρα",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Βήμα επισκευής:",
     "Repair info:" : "Πληροφορίες επισκευής:",
@@ -65,7 +62,7 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Εισάγετε το κλειδί συνδρομής σας στην εφαρμογή υποστήριξης για να αυξήσετε το όριο λογαριασμών. Αυτό σας παρέχει επίσης όλα τα πρόσθετα πλεονεκτήματα που προσφέρει το Nextcloud Enterprise και συνιστάται ιδιαίτερα για λειτουργία σε εταιρείες.",
     "Learn more ↗" : "Μάθετε περισσότερα ↗",
     "Preparing update" : "Προετοιμασία ενημέρωσης",
-    "Please use the command line updater because updating via browser is disabled in your config.php." : "Παρακαλούμε χρησιμοποιήστε το πρόγραμμα ενημέρωσης γραμμής εντολών, επειδή η ενημέρωση μέσω του προγράμματος περιήγησης είναι απενεργοποιημένη στο αρχείο config.php.",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Παρακαλούμε ενημερώστε μέσω γραμμής εντολών γιατί η ενημέρωση μέσω του browser είναι απενεργοποιημένη στο config.php.",
     "Turned on maintenance mode" : "Η λειτουργία συντήρησης ενεργοποιήθηκε",
     "Turned off maintenance mode" : "Η λειτουργία συντήρησης απενεργοποιήθηκε",
     "Maintenance mode is kept active" : "Η λειτουργία συντήρησης διατηρήθηκε ενεργή",
@@ -200,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Βίντεο Matroska",
     "Windows Media video" : "Βίντεο Windows Media",
     "AVI video" : "Βίντεο AVI",
-    "unknown text" : "άγνωστο κείμενο",
-    "Hello world!" : "Γεια σου κόσμε!",
-    "sunny" : "ηλιόλουστη",
-    "Hello {name}, the weather is {weather}" : "Γεια σου {name}, ο καιρός είναι {weather}",
-    "Hello {name}" : "Γεια σου {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Αυτά είναι τα αποτελέσματα της αναζήτησής σας<script>ειδοποίηση(1)</script></strong>",
-    "new" : "νέο",
-    "_download %n file_::_download %n files_" : ["λήψη %n αρχείου","λήψη %n αρχείων"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Η ενημέρωση είναι σε εξέλιξη, αποχωρώντας από αυτή τη σελίδα μπορεί να διακοπεί τη διαδικασία σε ορισμένα περιβάλλοντα.",
     "Update to {version}" : "Ενημέρωση στην έκδοση {version}",
     "An error occurred." : "Παρουσιάστηκε σφάλμα.",
@@ -215,7 +204,7 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Μη επιτυχημένη ενημέρωση. Για περισσότερες πληροφορίες <a href=\"{url}\">δείτε αυτή τη δημοσίευση στο forum</a> που καλύπτει αυτό το θέμα.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Μη επιτυχημένη ενημέρωση. Παρακαλούμε αναφέρετε αυτό το πρόβλημα στην <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">κοινότητα Nextcloud</a>.",
     "Continue to {productName}" : "Συνέχεια στο {productName}",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Η ενημέρωση ήταν επιτυχής. Ανακατεύθυνσή σας στο {productName} σε %n δευτερόλεπτο.","Η ενημέρωση ήταν επιτυχής. Ανακατεύθυνσή σας στο {productName} σε %n δευτερόλεπτα."],
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Η ενημέρωση ήταν επιτυχής. Ανακατεύθυνσή σας στο {productName} σε %n δευτερόλεπτο.","Η ενημέρωση ήταν επιτυχής. Θα ανακατευθυνθείτε στο {productName} σε %n δευτερόλεπτα."],
     "Applications menu" : "Μενού εφαρμογών",
     "Apps" : "Εφαρμογές",
     "More apps" : "Περισσότερες εφαρμογές",
@@ -237,8 +226,9 @@ OC.L10N.register(
     "Search in current app" : "Αναζήτηση στην τρέχουσα εφαρμογή",
     "Clear search" : "Εκκαθάριση αναζήτησης",
     "Search everywhere" : "Αναζητήστε παντού",
-    "Searching …" : "Γίνεται αναζήτηση ...",
+    "Searching …" : "Γίνεται αναζήτηση ...",
     "Start typing to search" : "Ξεκινήστε την πληκτρολόγηση για αναζήτηση",
+    "Minimum search length is {minSearchLength} characters" : "Ελάχιστο μήκος {minSearchLength}χαρακτήρες",
     "No matching results" : "Δεν υπάρχουν αποτελέσματα που να ταιριάζουν",
     "Today" : "Σήμερα",
     "Last 7 days" : "Τελευταίες 7 ημέρες",
@@ -258,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "Φόρτωση περισσοτέρων αποτελεσμάτων",
     "Search in" : "Αναζήτηση σε",
     "Log in" : "Είσοδος",
-    "Logging in …" : "Πραγματοποιείται είσοδος …",
+    "Logging in …" : "Πραγματοποιείται είσοδος …",
     "Log in to {productName}" : "Συνδεθείτε στο {productName}",
     "Wrong login or password." : "Εσφαλμένο όνομα χρήστη ή συνθηματικό.",
     "This account is disabled" : "Αυτός ο λογαριασμός είναι απενεργοποιημένος",
@@ -295,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Συνεργατικά έγγραφα, λογιστικά φύλλα και παρουσιάσεις, βασισμένα στο Collabora Online.",
     "Distraction free note taking app." : "Εφαρμογή λήψης σημειώσεων χωρίς περισπασμούς.",
     "Recommended apps" : "Προτεινόμενες εφαρμογές",
-    "Loading apps …" : "Γίνεται φόρτωση εφαρμογών …",
+    "Loading apps …" : "Γίνεται φόρτωση εφαρμογών …",
     "Could not fetch list of apps from the App Store." : "Δεν μπορεί να ληφθεί η λίστα εφαρμογών από το App Store.",
     "App download or installation failed" : "Η εγκατάσταση ή η λήψη εφαρμογής απέτυχε",
     "Cannot install this app because it is not compatible" : "Δεν είναι δυνατή η εγκατάσταση αυτής της εφαρμογής επειδή δεν είναι συμβατή",
     "Cannot install this app" : "Δεν είναι δυνατή η εγκατάσταση αυτής της εφαρμογής",
     "Skip" : "Παράλειψη",
-    "Installing apps …" : "Εγκατάσταση εφαρμογών …",
+    "Installing apps …" : "Εγκατάσταση εφαρμογών …",
     "Install recommended apps" : "Εγκατάσταση προτεινόμενων εφαρμογών",
     "Avatar of {displayName}" : "Avatar του {displayName}",
     "Settings menu" : "Μενού ρυθμίσεων",
-    "Loading your contacts …" : "Γίνεται φόρτωση των επαφών σας …",
-    "Looking for {term} …" : "Αναζήτηση για {term} …",
+    "Loading your contacts …" : "Φόρτωση των επαφών σας …",
+    "Looking for {term} …" : "Αναζήτηση για {term} …",
     "Search contacts" : "Αναζήτηση επαφών",
     "Reset search" : "Επαναφορά αναζήτησης",
-    "Search contacts …" : "Αναζήτηση επαφών …",
+    "Search contacts …" : "Αναζήτηση επαφών …",
     "Could not load your contacts" : "Αδυναμία φόρτωσης των επαφών σας",
     "No contacts found" : "Δεν βρέθηκαν επαφές",
     "Show all contacts" : "Εμφάνιση όλων των επαφών",
@@ -321,7 +311,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση για {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Η αναζήτηση ξεκινά μόλις αρχίσετε να πληκτρολογείτε και μπορείτε να επιλέξετε τα αποτελέσματα με τα πλήκτρα βέλους",
     "Search for {name} only" : "Αναζήτηση μόνο για {name}",
-    "Loading more results …" : "Γίνεται φόρτωση περισσότερων αποτελεσμάτων …",
+    "Loading more results …" : "Γίνεται φόρτωση περισσότερων αποτελεσμάτων …",
     "Forgot password?" : "Ξεχάσατε το συνθηματικό;",
     "Back to login form" : "Επιστροφή στη φόρμα σύνδεσης",
     "Back" : "Πίσω",
@@ -365,7 +355,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Παρακαλώ καθορίστε τον αριθμό της θύρας μαζί με το όνομα διακομιστή (πχ localhost: 5432).",
     "Database host" : "Διακομιστής βάσης δεδομένων",
     "localhost" : "localhost",
-    "Installing …" : "Γίνεται εγκατάσταση …",
+    "Installing …" : "Γίνεται εγκατάσταση …",
     "Install" : "Εγκατάσταση",
     "Need help?" : "Θέλετε βοήθεια;",
     "See the documentation" : "Δείτε την τεκμηρίωση",
@@ -374,7 +364,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ο περιηγητής σας δεν υποστηρίζεται. Κάντε αναβάθμιση σε νεότερη ή υποστηριζόμενη έκδοση.",
     "Continue with this unsupported browser" : "Συνέχεια με αυτό το μη υποστηριζόμενο πρόγραμμα περιήγησης",
     "Supported versions" : "Υποστηριζόμενες εκδόσεις",
-    "Search {types} …" : "Αναζήτηση {types} …",
+    "Search {types} …" : "Αναζήτηση {types} …",
     "Choose {file}" : "Επιλέξτε {file}",
     "Choose" : "Επιλέξτε",
     "Copy to {target}" : "Αντιγραφή σε {target}",
@@ -394,7 +384,7 @@ OC.L10N.register(
     "(all selected)" : "(όλα τα επιλεγμένα)",
     "({count} selected)" : "({count} επιλέχθηκαν)",
     "Error loading file exists template" : "Σφάλμα κατά την φόρτωση του προτύπου \"αρχείο υπάρχει\"",
-    "Saving …" : "Γίνεται αποθήκευση …",
+    "Saving …" : "Αποθήκευση ...",
     "seconds ago" : "δευτερόλεπτα πριν",
     "Connection to server lost" : "Η σύνδεση στον διακομιστή διακόπηκε",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Πρόβλημα φόρτωσης σελίδας, επαναφόρτωση σε %n δευτερόλεπτα","Πρόβλημα φόρτωσης σελίδας, επαναφόρτωση σε %n δευτερόλεπτα"],
@@ -409,17 +399,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Πληκτρολογήστε για αναζήτηση έργου",
     "New in" : "Νέο σε",
     "View changelog" : "Εμφάνιση αρχείου αλλαγών",
-    "No action available" : "Καμία διαθέσιμη ενέργεια",
-    "Error fetching contact actions" : "Σφάλμα κατά την λήψη ενεργειών της επαφής",
     "Close \"{dialogTitle}\" dialog" : "Κλείσιμο του διαλόγου \"{dialogTitle}\"",
     "Email length is at max (255)" : "Το μήκος του email είναι στο μέγιστο (255)",
-    "Non-existing tag #{tag}" : "Μη υπάρχουσα ετικέτα #{tag}",
-    "Restricted" : "Περιορισμένο",
-    "Invisible" : "Αόρατο",
-    "Delete" : "Διαγραφή",
-    "Rename" : "Μετονομασία",
-    "Collaborative tags" : "Συνεργατικές ετικέτες",
-    "No tags found" : "Δεν βρέθηκαν ετικέτες",
     "Clipboard not available, please copy manually" : "Το πρόχειρο δεν είναι διαθέσιμο, παρακαλούμε αντιγράψτε χειροκίνητα",
     "Personal" : "Προσωπικά",
     "Accounts" : "Λογαριασμοί",
@@ -497,7 +478,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Για να αποφύγετε τη λήξη χρόνου με μεγαλύτερες εγκαταστάσεις, μπορείτε αντί αυτού να εκτελέσετε την ακόλουθη εντολή στον κατάλογο εγκατάστασης:",
     "Detailed logs" : "Λεπτομερές ιστορικό",
     "Update needed" : "Απαιτείται ενημέρωση",
-    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Χρησιμοποιήστε το πρόγραμμα ενημέρωσης της γραμμής εντολών, επειδή έχετε μια μεγάλη εγκατάσταση με περισσότερους από 50 λογαριασμούς.",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Χρησιμοποιήστε την ενημέρωση μέσω γραμμής εντολών γιατί έχετε μεγάλη εγκατάσταση με περισσότερους από 50 λογαριασμούς.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Για βοήθεια, δείτε στην  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">τεκμηρίωση</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Γνωρίζω ότι συνεχίζοντας την ενημέρωση μέσω web UI αποτελεί ρίσκο, το χρονικό όριο του αιτήματος μπορεί να εξαντληθεί με συνέπεια το χάσιμο δεδομένων, αλλά έχω πραγματοποιήσει αντίγραφο ασφαλείας και γνωρίζω πως να κάνω αποκατάσταση σε περίπτωση αποτυχίας.",
     "Upgrade via web on my own risk" : "Αναβάθμιση μέσω ιστού με δική μου ευθύνη",
@@ -507,17 +488,44 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Επικοινωνήστε με το διαχειριστή του συστήματος αν αυτό το μήνυμα συνεχίζει να εμφανίζεται ή εμφανίστηκε απρόσμενα.",
     "Error occurred while checking server setup" : "Παρουσιάστηκε σφάλμα κατά τον έλεγχο των ρυθμίσεων του διακομιστή σας",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Για περισσότερες λεπτομέρειες, ανατρέξτε στη {linkstart}τεκμηρίωση ↗{linkend}.",
+    "unknown text" : "άγνωστο κείμενο",
+    "Hello world!" : "Γεια σου κόσμε!",
+    "sunny" : "ηλιόλουστη",
+    "Hello {name}, the weather is {weather}" : "Γεια σου {name}, ο καιρός είναι {weather}",
+    "Hello {name}" : "Γεια σου {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Αυτά είναι τα αποτελέσματα της αναζήτησής σας<script>ειδοποίηση(1)</script></strong>",
+    "new" : "νέο",
+    "_download %n file_::_download %n files_" : ["λήψη %n αρχείου","λήψη %n αρχείων"],
+    "Searching …" : "Γίνεται αναζήτηση ...",
+    "Logging in …" : "Πραγματοποιείται είσοδος …",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Μηνύματα, κλήσεις βίντεο, κοινή χρήση οθόνης, συναντήσεις και τηλεδιασκέψεις - στον περιηγητή σας και με εφαρμογές κινητού.",
+    "Loading apps …" : "Γίνεται φόρτωση εφαρμογών …",
+    "Installing apps …" : "Εγκατάσταση εφαρμογών …",
+    "Loading your contacts …" : "Γίνεται φόρτωση των επαφών σας …",
+    "Looking for {term} …" : "Αναζήτηση για {term} …",
+    "Search contacts …" : "Αναζήτηση επαφών …",
+    "Loading more results …" : "Γίνεται φόρτωση περισσότερων αποτελεσμάτων …",
     "You have not added any info yet" : "Δεν έχετε προσθέσει ακόμα πληροφορίες",
     "{user} has not added any info yet" : "{user} δεν έχει προσθέσει ακόμη πληροφορίες",
     "Error opening the user status modal, try hard refreshing the page" : "Σφάλμα κατά το άνοιγμα της κατάστασης χρήστη, δοκιμάστε να ανανεώσετε τη σελίδα",
     "Edit Profile" : "Επεξεργασία προφίλ",
     "The headline and about sections will show up here" : "Ο «τίτλος» και οι ενότητες «σχετικά με» θα εμφανιστούν εδώ",
+    "Search {types} …" : "Αναζήτηση {types} …",
+    "Saving …" : "Γίνεται αποθήκευση …",
     "Very weak password" : "Πολύ αδύναμο συνθηματικό",
     "Weak password" : "Αδύναμο συνθηματικό",
     "So-so password" : "Μέτριο συνθηματικό",
     "Good password" : "Καλό συνθηματικό",
     "Strong password" : "Δυνατό συνθηματικό",
+    "No action available" : "Καμία διαθέσιμη ενέργεια",
+    "Error fetching contact actions" : "Σφάλμα κατά την λήψη ενεργειών της επαφής",
+    "Non-existing tag #{tag}" : "Μη υπάρχουσα ετικέτα #{tag}",
+    "Restricted" : "Περιορισμένο",
+    "Invisible" : "Αόρατο",
+    "Delete" : "Διαγραφή",
+    "Rename" : "Μετονομασία",
+    "Collaborative tags" : "Συνεργατικές ετικέτες",
+    "No tags found" : "Δεν βρέθηκαν ετικέτες",
     "Profile not found" : "Το προφίλ δε βρέθηκε",
     "The profile does not exist." : "Το προφίλ δεν υπάρχει.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ο κατάλογος δεδομένων και τα αρχεία σας είναι πιθανό να είναι προσβάσιμα από το διαδίκτυο διότι δεν δουλεύει το αρχείο .htaccess.",
@@ -530,6 +538,7 @@ OC.L10N.register(
     "Configure the database" : "Ρύθμιση της βάσης δεδομένων",
     "Only %s is available." : "Μόνο %s είναι διαθέσιμο.",
     "Database account" : "Λογαριασμός βάσης δεδομένων",
+    "Installing …" : "Γίνεται εγκατάσταση …",
     "Direct link copied to clipboard" : "Ο άμεσος σύνδεσμος αντιγράφηκε στο πρόχειρο"
 },
 "nplurals=2; plural=(n != 1);");
