@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Unknown filetype",
     "An error occurred. Please contact your admin." : "An error occurred. Please contact your admin.",
     "Invalid image" : "Invalid image",
-    "No temporary profile picture available, try again" : "No temporary profile picture available, try again",
-    "No crop data provided" : "No crop data provided",
-    "No valid crop data provided" : "No valid crop data provided",
-    "Crop is not square" : "Crop is not square",
     "State token does not match" : "State token does not match",
     "Invalid app password" : "Invalid app password",
     "Could not complete login" : "Could not complete login",
@@ -200,14 +196,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI video",
-    "unknown text" : "unknown text",
-    "Hello world!" : "Hello world!",
-    "sunny" : "sunny",
-    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
-    "Hello {name}" : "Hello {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
-    "new" : "new",
-    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "The update is in progress, leaving this page might interrupt the process in some environments.",
     "Update to {version}" : "Update to {version}",
     "An error occurred." : "An error occurred.",
@@ -237,7 +225,6 @@ OC.L10N.register(
     "Search in current app" : "Search in current app",
     "Clear search" : "Clear search",
     "Search everywhere" : "Search everywhere",
-    "Searching …" : "Searching …",
     "Start typing to search" : "Start typing to search",
     "No matching results" : "No matching results",
     "Today" : "Today",
@@ -258,7 +245,7 @@ OC.L10N.register(
     "Load more results" : "Load more results",
     "Search in" : "Search in",
     "Log in" : "Log in",
-    "Logging in …" : "Logging in …",
+    "Logging in …" : "Logging in …",
     "Log in to {productName}" : "Log in to {productName}",
     "Wrong login or password." : "Wrong login or password.",
     "This account is disabled" : "This account is disabled",
@@ -295,21 +282,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
     "Distraction free note taking app." : "Distraction free note taking app.",
     "Recommended apps" : "Recommended apps",
-    "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
     "App download or installation failed" : "App download or installation failed",
     "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
     "Cannot install this app" : "Cannot install this app",
     "Skip" : "Skip",
-    "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
     "Avatar of {displayName}" : "Avatar of {displayName}",
     "Settings menu" : "Settings menu",
-    "Loading your contacts …" : "Loading your contacts …",
-    "Looking for {term} …" : "Looking for {term} …",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
-    "Search contacts …" : "Search contacts …",
     "Could not load your contacts" : "Could not load your contacts",
     "No contacts found" : "No contacts found",
     "Show all contacts" : "Show all contacts",
@@ -321,7 +303,6 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Search starts once you start typing and results may be reached with the arrow keys",
     "Search for {name} only" : "Search for {name} only",
-    "Loading more results …" : "Loading more results …",
     "Forgot password?" : "Forgot password?",
     "Back to login form" : "Back to login form",
     "Back" : "Back",
@@ -365,7 +346,6 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Please specify the port number along with the host name (e.g., localhost:5432).",
     "Database host" : "Database host",
     "localhost" : "localhost",
-    "Installing …" : "Installing …",
     "Install" : "Install",
     "Need help?" : "Need help?",
     "See the documentation" : "See the documentation",
@@ -374,7 +354,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
-    "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
     "Copy to {target}" : "Copy to {target}",
@@ -394,7 +373,7 @@ OC.L10N.register(
     "(all selected)" : "(all selected)",
     "({count} selected)" : "({count} selected)",
     "Error loading file exists template" : "Error loading file exists template",
-    "Saving …" : "Saving …",
+    "Saving …" : "Saving …",
     "seconds ago" : "seconds ago",
     "Connection to server lost" : "Connection to server lost",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem loading page, reloading in %n second","Problem loading page, reloading in %n seconds"],
@@ -409,17 +388,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type to search for existing projects",
     "New in" : "New in",
     "View changelog" : "View changelog",
-    "No action available" : "No action available",
-    "Error fetching contact actions" : "Error fetching contact actions",
     "Close \"{dialogTitle}\" dialog" : "Close \"{dialogTitle}\" dialogue",
     "Email length is at max (255)" : "Email length is at max (255)",
-    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
-    "Restricted" : "Restricted",
-    "Invisible" : "Invisible",
-    "Delete" : "Delete",
-    "Rename" : "Rename",
-    "Collaborative tags" : "Collaborative tags",
-    "No tags found" : "No tags found",
     "Clipboard not available, please copy manually" : "Clipboard not available, please copy manually",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
@@ -507,17 +477,44 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contact your system administrator if this message persists or appeared unexpectedly.",
     "Error occurred while checking server setup" : "Error occurred whilst checking server setup",
     "For more details see the {linkstart}documentation ↗{linkend}." : "For more details see the {linkstart}documentation ↗{linkend}.",
+    "unknown text" : "unknown text",
+    "Hello world!" : "Hello world!",
+    "sunny" : "sunny",
+    "Hello {name}, the weather is {weather}" : "Hello {name}, the weather is {weather}",
+    "Hello {name}" : "Hello {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>These are your search results<script>alert(1)</script></strong>",
+    "new" : "new",
+    "_download %n file_::_download %n files_" : ["download %n file","download %n files"],
+    "Searching …" : "Searching …",
+    "Logging in …" : "Logging in …",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
+    "Loading apps …" : "Loading apps …",
+    "Installing apps …" : "Installing apps …",
+    "Loading your contacts …" : "Loading your contacts …",
+    "Looking for {term} …" : "Looking for {term} …",
+    "Search contacts …" : "Search contacts …",
+    "Loading more results …" : "Loading more results …",
     "You have not added any info yet" : "You have not added any info yet",
     "{user} has not added any info yet" : "{user} has not added any info yet",
     "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
     "Edit Profile" : "Edit Profile",
     "The headline and about sections will show up here" : "The headline and about sections will show up here",
+    "Search {types} …" : "Search {types} …",
+    "Saving …" : "Saving …",
     "Very weak password" : "Very weak password",
     "Weak password" : "Weak password",
     "So-so password" : "So-so password",
     "Good password" : "Good password",
     "Strong password" : "Strong password",
+    "No action available" : "No action available",
+    "Error fetching contact actions" : "Error fetching contact actions",
+    "Non-existing tag #{tag}" : "Non-existing tag #{tag}",
+    "Restricted" : "Restricted",
+    "Invisible" : "Invisible",
+    "Delete" : "Delete",
+    "Rename" : "Rename",
+    "Collaborative tags" : "Collaborative tags",
+    "No tags found" : "No tags found",
     "Profile not found" : "Profile not found",
     "The profile does not exist." : "The profile does not exist.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Your data directory and files are probably accessible from the internet because the .htaccess file does not work.",
@@ -530,6 +527,7 @@ OC.L10N.register(
     "Configure the database" : "Configure the database",
     "Only %s is available." : "Only %s is available.",
     "Database account" : "Database account",
+    "Installing …" : "Installing …",
     "Direct link copied to clipboard" : "Direct link copied to clipboard"
 },
 "nplurals=2; plural=(n != 1);");
