@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Type de fichier inconnu",
     "An error occurred. Please contact your admin." : "Une erreur est survenue. Veuillez contacter un administrateur.",
     "Invalid image" : "Image invalide",
-    "No temporary profile picture available, try again" : "Aucune image de profil temporaire disponible, essayez à nouveau",
-    "No crop data provided" : "Aucune donnée de recadrage fournie",
-    "No valid crop data provided" : "Aucune donnée valide de recadrage fournie",
-    "Crop is not square" : "Le recadrage n’est pas carré",
     "State token does not match" : "Les jetons de statut ne correspondent pas",
     "Invalid app password" : "Mot de passe d’application non valide",
     "Could not complete login" : "Impossible de terminer la connexion",
@@ -40,10 +36,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquez sur le bouton suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, vous pouvez ignorer cet e-mail.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquer sur le lien suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, alors ignorez cet e-mail.",
     "Reset your password" : "Réinitialiser votre mot de passe",
-    "The given provider is not available" : "Le fournisseur donné n'est pas disponible",
+    "The given provider is not available" : "Le fournisseur indiqué n'est pas disponible",
     "Task not found" : "Tâche non trouvée",
     "Internal error" : "Erreur interne",
     "Not found" : "Non trouvé",
+    "Node is locked" : "Le noeud est verrouillé",
     "Bad request" : "Requête erronée",
     "Requested task type does not exist" : "Le type de tâche demandé n’existe pas",
     "Necessary language model provider is not available" : "Le fournisseur de modèle de langage nécessaire n’est pas disponible",
@@ -52,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Aucun fournisseur de traduction n’est disponible",
     "Could not detect language" : "Impossible de détecter la langue",
     "Unable to translate" : "Impossible de traduire",
+    "No valid filters provided" : "Aucun filtre valide fourni",
     "[%d / %d]: %s" : "[%d / %d] : %s",
     "Repair step:" : "Étape de réparation :",
     "Repair info:" : "Informations de réparation :",
@@ -73,15 +71,18 @@ OC.L10N.register(
     "Update app \"%s\" from App Store" : "Mise à jour l’application « %s » depuis le magasin d’applications",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
     "Updated \"%1$s\" to %2$s" : "Mise à jour de « %1$s » vers %2$s",
-    "Set log level to debug" : "Réglage du niveau de journalisation à « débogage »",
-    "Reset log level" : "Réinitialisation du niveau de journalisation",
+    "Set log level to debug" : "Définir le niveau de journalisation sur débogage",
+    "Reset log level" : "Réinitialiser le niveau de journalisation",
     "Starting code integrity check" : "Lancement de la vérification d’intégrité du code",
     "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
     "%s (incompatible)" : "%s (incompatible)",
     "The following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
     "Already up to date" : "Déjà à jour",
+    "Windows Command Script" : "Script de commande Windows",
     "Electronic book document" : "Livre électronique",
-    "GPX geographic data" : "Donnée géographique GPX",
+    "TrueType Font Collection" : "Collection de police TrueType",
+    "Web Open Font Format" : "Format Web Open Font",
+    "GPX geographic data" : "Données géographiques GPX",
     "Gzip archive" : "Archive Gzip",
     "Adobe Illustrator document" : "Document Adobe Illustrator",
     "Java source code" : "Code source Java",
@@ -95,30 +96,30 @@ OC.L10N.register(
     "PostScript document" : "Document PostScript",
     "RSS summary" : "Résumé RSS",
     "Android package" : "Paquet Android",
-    "KML geographic data" : "Donné géographique KML",
-    "KML geographic compressed data" : "Donnée géographique compressée KML",
+    "KML geographic data" : "Données géographiques KML",
+    "KML geographic compressed data" : "Données géographiques compressées KML",
     "Lotus Word Pro document" : "Document Lotus Word Pro",
     "Excel spreadsheet" : "Feuille de calcul Excel",
-    "Excel add-in" : "Complément Excel",
+    "Excel add-in" : "Extension Excel",
     "Excel 2007 binary spreadsheet" : "Feuille de calcul binaire Excel 2007",
     "Excel spreadsheet template" : "Modèle de feuille de calcul Excel",
     "Outlook Message" : "Message Outlook",
     "PowerPoint presentation" : "Présentation Powerpoint",
-    "PowerPoint add-in" : "Complément PowerPoint",
+    "PowerPoint add-in" : "Extension PowerPoint",
     "PowerPoint presentation template" : "Modèle de présentation PowerPoint",
     "Word document" : "Document Word",
     "ODF formula" : "Formule ODF",
     "ODG drawing" : "Dessin ODG",
-    "ODG drawing (Flat XML)" : "Dessin ODG (XML à plat)",
+    "ODG drawing (Flat XML)" : "Dessin ODG (Flat XML)",
     "ODG template" : "Modèle ODG",
     "ODP presentation" : "Présentation ODP",
-    "ODP presentation (Flat XML)" : "Présentation ODP (XML à plat)",
+    "ODP presentation (Flat XML)" : "Présentation ODP (Flat XML)",
     "ODP template" : "Modèle ODP",
     "ODS spreadsheet" : "Feuille de calcul ODS",
-    "ODS spreadsheet (Flat XML)" : "Feuille de calcul ODS (XML à plat)",
+    "ODS spreadsheet (Flat XML)" : "Feuille de calcul ODS (Flat XML)",
     "ODS template" : "Modèle ODS",
     "ODT document" : "Document ODT",
-    "ODT document (Flat XML)" : "Document ODF (XML à plat)",
+    "ODT document (Flat XML)" : "Document ODF (Flat XML)",
     "ODT template" : "Modèle ODT",
     "PowerPoint 2007 presentation" : "Présentation PowerPoint 2007",
     "PowerPoint 2007 show" : "Diaporama PowerPoint 2007",
@@ -168,7 +169,7 @@ OC.L10N.register(
     "WebP image" : "Image WebP",
     "Digital raw image" : "Image Digital raw",
     "Windows Icon" : "Icône Windows",
-    "Email message" : "Courrier électronique",
+    "Email message" : "E-mail",
     "VCS/ICS calendar" : "Calendrier VCS/ICS",
     "CSS stylesheet" : "Feuille de style CSS",
     "CSV document" : "Document CSV",
@@ -196,16 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Vidéo Matroska",
     "Windows Media video" : "Vidéo Windows Media",
     "AVI video" : "Vidéo AVI",
-    "Error occurred while checking server setup" : "Une erreur s’est produite lors de la vérification de la configuration du serveur",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
-    "unknown text" : "texte inconnu",
-    "Hello world!" : "Hello world!",
-    "sunny" : "ensoleillé",
-    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
-    "Hello {name}" : "Bonjour {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
-    "new" : "nouveau ",
-    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
     "Update to {version}" : "Mettre à jour vers {version}",
     "An error occurred." : "Une erreur est survenue.",
@@ -222,11 +213,11 @@ OC.L10N.register(
     "Yes" : "Oui",
     "The remote URL must include the user." : "L'URL distante doit inclure l'utilisateur.",
     "Invalid remote URL." : "URL distante invalide.",
-    "Failed to add the public link to your Nextcloud" : "Échec de l'ajout du lien public à votre Nextcloud",
+    "Failed to add the public link to your Nextcloud" : "Impossible d'ajouter le lien public à votre Nextcloud",
     "Federated user" : "Utilisateur fédéré",
     "user@your-nextcloud.org" : "utilisateur@votre-nextcloud.org",
     "Create share" : "Créer un partage",
-    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers",
+    "Direct link copied" : "Lien direct copié",
     "Please copy the link manually:" : "Veuillez copier le lien manuellement :",
     "Custom date range" : "Plage de dates personnalisée",
     "Pick start date" : "Sélectionner une date de début",
@@ -235,7 +226,6 @@ OC.L10N.register(
     "Search in current app" : "Recherche dans l'application courante",
     "Clear search" : "Effacer la recherche",
     "Search everywhere" : "Chercher partout",
-    "Searching …" : "Recherche…",
     "Start typing to search" : "Commencez à taper pour lancer la recherche",
     "No matching results" : "Aucun résultat correspondant",
     "Today" : "Aujourd’hui",
@@ -243,6 +233,7 @@ OC.L10N.register(
     "Last 30 days" : "30 derniers jours",
     "This year" : "Cette année",
     "Last year" : "Année dernière",
+    "Between {startDate} and {endDate}" : "Entre le {startDate} et le {endDate}",
     "Unified search" : "Recherche unifiée",
     "Search apps, files, tags, messages" : "Rechercher des applications, des fichiers, des étiquettes, des messages",
     "Places" : "Emplacements",
@@ -250,11 +241,12 @@ OC.L10N.register(
     "Search people" : "Rechercher des personnes",
     "People" : "Personnes",
     "Filter in current view" : "Filtrer dans la vue actuelle",
+    "Search connected services" : "Services connectés de recherche",
     "Results" : "Résultats",
     "Load more results" : "Charger plus de résultats",
     "Search in" : "Rechercher dans",
     "Log in" : "Se connecter",
-    "Logging in …" : "Connexion…",
+    "Logging in …" : "Connexion en cours…",
     "Log in to {productName}" : "Se connecter à {productName}",
     "Wrong login or password." : "Mauvais identifiant ou mot de passe.",
     "This account is disabled" : "Ce compte est désactivé",
@@ -291,21 +283,16 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, feuilles de calculs ou présentations créées sur Collabora Online.",
     "Distraction free note taking app." : "Application de prise de notes sans distraction.",
     "Recommended apps" : "Applications recommandées",
-    "Loading apps …" : "Chargement des applis…",
     "Could not fetch list of apps from the App Store." : "Impossible de récupérer la liste des applications depuis le magasin d’applications",
     "App download or installation failed" : "Échec lors du téléchargement ou de l’installation de l’application",
     "Cannot install this app because it is not compatible" : "Impossible d’installer cette app parce qu’elle n’est pas compatible",
     "Cannot install this app" : "Impossible d’installer cette app",
     "Skip" : "Ignorer",
-    "Installing apps …" : "Installation des applis en cours...",
     "Install recommended apps" : "Installer les applications recommandées",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menu des paramètres",
-    "Loading your contacts …" : "Chargement de vos contacts...",
-    "Looking for {term} …" : "Recherche de {term} ...",
     "Search contacts" : "Rechercher des contacts",
     "Reset search" : "Réinitialiser la recherche",
-    "Search contacts …" : "Rechercher un contact...",
     "Could not load your contacts" : "Impossible de charger vos contacts",
     "No contacts found" : "Aucun contact trouvé",
     "Show all contacts" : "Afficher tous les contacts",
@@ -314,16 +301,20 @@ OC.L10N.register(
     "No results for {query}" : "Aucun résultat pour {query}",
     "Press Enter to start searching" : "Appuyer sur Entrée pour démarrer la recherche",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
-    "An error occurred while searching for {type}" : "Une erreur s’est produite lors de la recherche de {type}",
+    "An error occurred while searching for {type}" : "Une erreur est survenue lors de la recherche de {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La recherche démarre dès que vous commencez à taper et les résultats peuvent être atteints avec les flèches du clavier",
     "Search for {name} only" : "Rechercher pour {name} uniquement",
-    "Loading more results …" : "Chargement de plus de résultats …",
     "Forgot password?" : "Mot de passe oublié ?",
     "Back to login form" : "Retour au formulaire de connexion",
     "Back" : "Retour",
     "Login form is disabled." : "Le formulaire de connexion est désactivé.",
-    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez votre administration.",
-    "More actions" : "Plus d'actions…",
+    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez un administrateur.",
+    "More actions" : "Plus d'actions",
+    "User menu" : "Menu utilisateur",
+    "Your guest name: {user}" : "Votre nom d'invité : {user}",
+    "You are currently not identified." : "Vous n'êtes actuellement pas identifié.",
+    "Set public name" : "Définir le nom public",
+    "Change public name" : "Changer le nom public",
     "Password is too weak" : "Mot de passe trop faible",
     "Password is weak" : "Mot de passe faible",
     "Password is average" : "Mot de passe moyen",
@@ -355,7 +346,7 @@ OC.L10N.register(
     "Database tablespace" : "Espace de stockage de la base de données",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
     "Database host" : "Hôte de la base de données",
-    "Installing …" : "Installation...",
+    "localhost" : "localhost",
     "Install" : "Installer",
     "Need help?" : "Besoin d’aide ?",
     "See the documentation" : "Lire la documentation",
@@ -364,7 +355,6 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
     "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
     "Supported versions" : "Versions supportées",
-    "Search {types} …" : "Rechercher {types}…",
     "Choose {file}" : "Choisir {file}",
     "Choose" : "Choisir",
     "Copy to {target}" : "Copier vers {target}",
@@ -384,7 +374,7 @@ OC.L10N.register(
     "(all selected)" : "(tous sélectionnés)",
     "({count} selected)" : "({count} sélectionné(s))",
     "Error loading file exists template" : "Erreur lors du chargement du modèle de fichier existant",
-    "Saving …" : "Enregistrement...",
+    "Saving …" : "Enregistrement  …",
     "seconds ago" : "Il y a quelques secondes",
     "Connection to server lost" : "La connexion au serveur a été perdue",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
@@ -399,23 +389,15 @@ OC.L10N.register(
     "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
     "New in" : "Nouveau dans",
     "View changelog" : "Voir le journal des modifications",
-    "No action available" : "Aucune action disponible",
-    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
     "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue « {dialogTitle} »",
     "Email length is at max (255)" : "La longueur de l'e-mail est au maximum (255)",
-    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
-    "Restricted" : "Restreint",
-    "Invisible" : "Invisible",
-    "Delete" : "Supprimer",
-    "Rename" : "Renommer",
-    "Collaborative tags" : "Étiquettes collaboratives ",
-    "No tags found" : "Aucune étiquette n’a été trouvée",
     "Clipboard not available, please copy manually" : "Le presse-papier n'est pas disponible, veuillez copier manuellement",
     "Personal" : "Personnel",
     "Accounts" : "Comptes",
     "Admin" : "Administration",
     "Help" : "Aide",
     "Access forbidden" : "Accès non autorisé",
+    "You are not allowed to access this page." : "Vous n'êtes pas autorisé à accéder à cette page.",
     "Back to %s" : "Retour à %s",
     "Page not found" : "Page non trouvée",
     "The page could not be found on the server or you may not be allowed to view it." : "La page n'a pas pu être trouvée sur le serveur ou vous n'avez pas le droit de la visualiser.",
@@ -425,7 +407,7 @@ OC.L10N.register(
     "Internal Server Error" : "Erreur interne du serveur",
     "The server was unable to complete your request." : "Le serveur est incapable d'exécuter votre requête.",
     "If this happens again, please send the technical details below to the server administrator." : "Si cela se reproduit, veuillez envoyer les détails techniques ci-dessous à l'administrateur du serveur.",
-    "More details can be found in the server log." : "Le fichier journal du serveur peut fournir plus de renseignements.",
+    "More details can be found in the server log." : "Le fichier log du serveur peut fournir plus de renseignements.",
     "For more details see the documentation ↗." : "Pour plus de détails, voir la documentation ↗.",
     "Technical details" : "Renseignements techniques",
     "Remote Address: %s" : "Adresse distante : %s",
@@ -448,7 +430,7 @@ OC.L10N.register(
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
     "App password" : "Mot de passe d'application",
     "Grant access" : "Autoriser l'accès",
-    "Alternative log in using app password" : "Authentification alternative en utilisant un mot de passe d'application",
+    "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
     "Account access" : "Accès au compte",
     "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s ».",
@@ -484,7 +466,7 @@ OC.L10N.register(
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu’une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
     "Start update" : "Démarrer la mise à jour",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
-    "Detailed logs" : "Journaux détaillés",
+    "Detailed logs" : "Logs détaillés",
     "Update needed" : "Mise à jour nécessaire",
     "Please use the command line updater because you have a big instance with more than 50 accounts." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 comptes.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
@@ -494,28 +476,59 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
     "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
+    "Error occurred while checking server setup" : "Une erreur est survenue lors de la vérification de la configuration du serveur",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
+    "unknown text" : "texte inconnu",
+    "Hello world!" : "Hello world!",
+    "sunny" : "ensoleillé",
+    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
+    "Hello {name}" : "Bonjour {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
+    "new" : "nouveau ",
+    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
+    "Searching …" : "Recherche…",
+    "Logging in …" : "Connexion…",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d’écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
+    "Loading apps …" : "Chargement des applis…",
+    "Installing apps …" : "Installation des applis en cours...",
+    "Loading your contacts …" : "Chargement de vos contacts...",
+    "Looking for {term} …" : "Recherche de {term} ...",
+    "Search contacts …" : "Rechercher un contact...",
+    "Loading more results …" : "Chargement de plus de résultats …",
     "You have not added any info yet" : "Vous n’avez pas ajouté d’informations pour le moment",
     "{user} has not added any info yet" : "{user} n’a pas ajouté d’informations pour le moment",
     "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
     "Edit Profile" : "Modifier le profil",
     "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
+    "Search {types} …" : "Rechercher {types}…",
+    "Saving …" : "Enregistrement...",
     "Very weak password" : "Mot de passe très faible",
     "Weak password" : "Mot de passe faible",
     "So-so password" : "Mot de passe tout juste acceptable",
     "Good password" : "Mot de passe de sécurité suffisante",
     "Strong password" : "Mot de passe fort",
+    "No action available" : "Aucune action disponible",
+    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
+    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
+    "Restricted" : "Restreint",
+    "Invisible" : "Invisible",
+    "Delete" : "Supprimer",
+    "Rename" : "Renommer",
+    "Collaborative tags" : "Étiquettes collaboratives ",
+    "No tags found" : "Aucune étiquette n’a été trouvée",
     "Profile not found" : "Profile introuvable",
     "The profile does not exist." : "Le profile n'existe pas.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
     "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
     "New admin account name" : "Nouveau nom de compte administrateur",
-    "New admin password" : "Nouveau mot de passe admin",
+    "New admin password" : "Nouveau mot de passe administrateur",
     "Show password" : "Afficher le mot de passe",
     "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
     "Configure the database" : "Configurer la base de données",
     "Only %s is available." : "Seul(e) %s est disponible.",
-    "Database account" : "Compte de base de données"
+    "Database account" : "Compte de base de données",
+    "Installing …" : "Installation...",
+    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
