@@ -18,15 +18,12 @@ OC.L10N.register(
     "Unknown filetype" : "Óþekkt skráartegund",
     "An error occurred. Please contact your admin." : "Villa kom upp. Hafðu samband við kerfisstjóra.",
     "Invalid image" : "Ógild mynd",
-    "No temporary profile picture available, try again" : "Engin bráðabirgða-auðkennismynd er tiltæk, reyndu aftur",
-    "No crop data provided" : "Enginn gögn um utanskurð gefin",
-    "No valid crop data provided" : "Enginn gild gögn um utanskurð gefin",
-    "Crop is not square" : "Utanskurður er ekki ferningslaga",
     "State token does not match" : "Stöðuteikn samsvarar ekki",
     "Invalid app password" : "Ógilt lykilorð forrits",
     "Could not complete login" : "Gat ekki lokið innskráningu",
     "State token missing" : "Stöðuteikn vantar",
     "Your login token is invalid or has expired" : "Innskráningartákn er ógilt eða útrunnið",
+    "Please use original client" : "Þú ættir að nota upprunalegt biðlaraforrit",
     "This community release of Nextcloud is unsupported and push notifications are limited." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru takmarkaðar.",
     "Login" : "Innskráning",
     "Unsupported email length (>255)" : "Óstudd lengd tölvupósts (>255)",
@@ -43,6 +40,7 @@ OC.L10N.register(
     "Task not found" : "Verk fannst ekki",
     "Internal error" : "Innri villa",
     "Not found" : "Fannst ekki",
+    "Node is locked" : "Liður er læstur",
     "Bad request" : "Ógild beiðni",
     "Requested task type does not exist" : "Umbeðin tegund verks er ekki til",
     "Necessary language model provider is not available" : "Nauðsynleg tungumálslíkanaþjónusta er tiltæk",
@@ -51,6 +49,12 @@ OC.L10N.register(
     "No translation provider available" : "Engin þýðingaþjónusta tiltæk",
     "Could not detect language" : "Gat ekki greint tungumálið",
     "Unable to translate" : "Næ ekki að þýða",
+    "No valid filters provided" : "Engar gildar síur uppgefnar",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair step:" : "Þrep viðgerðar:",
+    "Repair info:" : "Viðgerðarupplýsingar:",
+    "Repair warning:" : "Viðvörun vegna viðgerðar:",
+    "Repair error:" : "Villa í viðgerð:",
     "Nextcloud Server" : "Nextcloud þjónn",
     "Some of your link shares have been removed" : "Sumir tenglar þínir á sameignir hafa verið fjarlægðir",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Vegna öryggisgalla hafa sumir tenglar þínir á sameignir hafa verið fjarlægðir. Skoðaðu tengilinn til að sjá frekari upplýsingar.",
@@ -58,11 +62,6 @@ OC.L10N.register(
     "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Settu inn áskriftarlykilinn þinn í aðstoðarforritið til að lyfta takmörkum á aðgangnum þínum. Þetta gefur þér einnig alla viðbótareiginleikana sem Nextcloud Enterprise fyrirtækjaáskrift býður, enda er sterklega mælt með þeim fyrir verklag í fyrirtækjum.",
     "Learn more ↗" : "Kanna nánar ↗",
     "Preparing update" : "Undirbý uppfærslu",
-    "[%d / %d]: %s" : "[%d / %d]: %s",
-    "Repair step:" : "Þrep viðgerðar:",
-    "Repair info:" : "Viðgerðarupplýsingar:",
-    "Repair warning:" : "Viðvörun vegna viðgerðar:",
-    "Repair error:" : "Villa í viðgerð:",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Endilega notaðu uppfærslutólið af skipanalínu, því uppfærslur í vafra eru gerðar óvirkar í config.php.",
     "Turned on maintenance mode" : "Kveikt á viðhaldsham",
     "Turned off maintenance mode" : "Slökkt á viðhaldsham",
@@ -79,16 +78,125 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (ósamhæft)",
     "The following apps have been disabled: %s" : "Eftirfarandi forrit hafa verið gerð óvirk: %s",
     "Already up to date" : "Allt uppfært nú þegar",
-    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
-    "unknown text" : "óþekktur texti",
-    "Hello world!" : "Halló heimur!",
-    "sunny" : "sólríkt",
-    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
-    "Hello {name}" : "Halló {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
-    "new" : "nýtt",
-    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
+    "Windows Command Script" : "Windows skeljarskrifta",
+    "Electronic book document" : "Rafbókarskjal",
+    "TrueType Font Collection" : "TrueType letursafn",
+    "Web Open Font Format" : "Web Open Font Format vefletur",
+    "GPX geographic data" : "GPX-hnattstaðsetningargögn",
+    "Gzip archive" : "Gzip-safnskrá",
+    "Adobe Illustrator document" : "Adobe Illustrator skjal",
+    "Java source code" : "Java-frumkóði",
+    "JavaScript source code" : "JavaScript-frumkóði",
+    "JSON document" : "JSON-skjal",
+    "Microsoft Access database" : "Microsoft Access gagnagrunnsskrá",
+    "Microsoft OneNote document" : "Microsoft OneNote-skjal",
+    "Microsoft Word document" : "Microsoft Word-skjal",
+    "Unknown" : "Óþekkt",
+    "PDF document" : "PDF-skjal",
+    "PostScript document" : "PostScript-skjal",
+    "RSS summary" : "RSS-samantekt",
+    "Android package" : "Android-pakki",
+    "KML geographic data" : "KML-hnattstaðsetningargögn",
+    "KML geographic compressed data" : "KML þjöppuð hnattstaðsetningargögn",
+    "Lotus Word Pro document" : "Lotus Word Pro skjal",
+    "Excel spreadsheet" : "Excel-töflureikniskjal",
+    "Excel add-in" : "Excel-viðbót",
+    "Excel 2007 binary spreadsheet" : "Excel tvíundarkerfis-töflureikniskjal",
+    "Excel spreadsheet template" : "Excel-töflureiknisniðmát",
+    "Outlook Message" : "Outlook-skilaboð",
+    "PowerPoint presentation" : "PowerPoint-kynning",
+    "PowerPoint add-in" : "PowerPoint-viðbót",
+    "PowerPoint presentation template" : "PowerPoint sniðmát fyrir glærukynningu",
+    "Word document" : "Word-skjal",
+    "ODF formula" : "ODF-formúla",
+    "ODG drawing" : "ODG-teikning",
+    "ODG drawing (Flat XML)" : "ODG-teikning (flatt XML)",
+    "ODG template" : "ODG-sniðmát",
+    "ODP presentation" : "ODP-kynning",
+    "ODP presentation (Flat XML)" : "ODP-glærukynning (flatt XML)",
+    "ODP template" : "ODP-sniðmát",
+    "ODS spreadsheet" : "ODS-töflureikniskjal",
+    "ODS spreadsheet (Flat XML)" : "ODS-töflureikniskjal (flatt XML)",
+    "ODS template" : "ODS-sniðmát",
+    "ODT document" : "ODT-skjal",
+    "ODT document (Flat XML)" : "ODT-skjal (flatt XML)",
+    "ODT template" : "ODT-sniðmát",
+    "PowerPoint 2007 presentation" : "PowerPoint 2007 kynning",
+    "PowerPoint 2007 show" : "PowerPoint 2007 glærusýning",
+    "PowerPoint 2007 presentation template" : "PowerPoint 2007 sniðmát fyrir glærukynningu",
+    "Excel 2007 spreadsheet" : "Excel 2007 töflureikniskjal",
+    "Excel 2007 spreadsheet template" : "Excel 2007 töflureiknisniðmát",
+    "Word 2007 document" : "Word 2007 skjal",
+    "Word 2007 document template" : "Word-sniðmát fyrir textaskjal",
+    "Microsoft Visio document" : "Microsoft Visio-skjal",
+    "WordPerfect document" : "WordPerfect-skjal",
+    "7-zip archive" : "7-zip safnskrá",
+    "Blender scene" : "Blender-sviðsmynd",
+    "Bzip2 archive" : "Bzip2-safnskrá",
+    "Debian package" : "Debian-pakki",
+    "FictionBook document" : "FictionBook-skjal",
+    "Unknown font" : "Óþekkt letur",
+    "Krita document" : "Krita-skjal",
+    "Mobipocket e-book" : "Mobipocket-rafbók",
+    "Windows Installer package" : "Windows-uppsetningarpakki",
+    "Perl script" : "Perl-skrifta",
+    "PHP script" : "PHP-skrifta",
+    "Tar archive" : "Tar-safnskrá",
+    "XML document" : "XML-skjal",
+    "YAML document" : "YAML-skjal",
+    "Zip archive" : "Zip-safnskrá",
+    "Zstandard archive" : "Zstandard-safnskrá",
+    "AAC audio" : "AAC-hljóðskrá",
+    "FLAC audio" : "FLAC-hljóðskrá",
+    "MPEG-4 audio" : "MPEG-4 hljóðskrá",
+    "MP3 audio" : "MP3-hljóðskrá",
+    "Ogg audio" : "Ogg-hljóðskrá",
+    "RIFF/WAVe standard Audio" : "Stöðluð RIFF/WAVe hljóðskrá",
+    "WebM audio" : "WebM-hljóðskrá",
+    "MP3 ShoutCast playlist" : "MP3 ShoutCast spilunarlisti",
+    "Windows BMP image" : "Windows BMP-mynd",
+    "Better Portable Graphics image" : "Better Portable Graphics mynd",
+    "EMF image" : "EMF-mynd",
+    "GIF image" : "GIF-mynd",
+    "HEIC image" : "HEIC-mynd",
+    "HEIF image" : "HEIF-mynd",
+    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 mynd",
+    "JPEG image" : "JPEG-mynd",
+    "PNG image" : "PNG-mynd",
+    "SVG image" : "SVG-mynd",
+    "Truevision Targa image" : "Truevision Targa mynd",
+    "TIFF image" : "TIFF-mynd",
+    "WebP image" : "WebP-mynd",
+    "Digital raw image" : "Stafræn RAW-mynd",
+    "Windows Icon" : "Windows-táknmynd",
+    "Email message" : "Tölvupóstskilaboð",
+    "VCS/ICS calendar" : "VCS/ICS-dagatal",
+    "CSS stylesheet" : "CSS-stílsnið",
+    "CSV document" : "CSV-skjal",
+    "HTML document" : "HTML-skjal",
+    "Markdown document" : "Markdown-skjal",
+    "Org-mode file" : "Org-mode skrá",
+    "Plain text document" : "Hreint textaskjal",
+    "Rich Text document" : "Ríkulega sniðið RTF-textaskjal",
+    "Electronic business card" : "Rafrænt nafnspjald",
+    "C++ source code" : "C++ frumkóði",
+    "LDIF address book" : "LDIF-nafnaskrá",
+    "NFO document" : "NFO-skjal",
+    "PHP source" : "PHP-grunntilfang",
+    "Python script" : "Python-skrifta",
+    "ReStructuredText document" : "ReStructuredText-skjal",
+    "3GPP multimedia file" : "3GPP-margmiðlunarskrá",
+    "MPEG video" : "MPEG-myndskeið",
+    "DV video" : "DV-myndskeið",
+    "MPEG-2 transport stream" : "MPEG-2 transport streymi",
+    "MPEG-4 video" : "MPEG-4 myndskeið",
+    "Ogg video" : "Ogg-myndskeið",
+    "QuickTime video" : "QuickTime myndskeið",
+    "WebM video" : "WebM-myndskeið",
+    "Flash video" : "Flash-myndskeið",
+    "Matroska video" : "Matroska-myndskeið",
+    "Windows Media video" : "Windows Media myndskeið",
+    "AVI video" : "AVI-myndskeið",
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Uppfærslan er í gangi, ef farið er af þessari síðu gæti það truflað ferlið á sumum kerfum.",
     "Update to {version}" : "Uppfæra í {version}",
     "An error occurred." : "Villa átti sér stað.",
@@ -109,7 +217,7 @@ OC.L10N.register(
     "Federated user" : "Notandi í skýjasambandi",
     "user@your-nextcloud.org" : "notandi@þitt-nextcloud.org",
     "Create share" : "Búa til sameign",
-    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald",
+    "Direct link copied" : "Beinn tengill afritaður",
     "Please copy the link manually:" : "Afritaðu tengilinn handvirkt:",
     "Custom date range" : "Sérsniðið dagsetningabil",
     "Pick start date" : "Veldu upphafsdagsetningu",
@@ -118,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Leita í núverandi forriti",
     "Clear search" : "Hreinsa leit",
     "Search everywhere" : "Leita allsstaðar",
-    "Searching …" : "Leita …",
+    "Searching …" : "Leita …",
     "Start typing to search" : "Skrifaðu hér til að leita",
+    "Minimum search length is {minSearchLength} characters" : "Lágmarkslengd leitarstrengs er {minSearchLength} stafir",
     "No matching results" : "Engar samsvarandi niðurstöður",
     "Today" : "Í dag",
     "Last 7 days" : "Síðustu 7 daga",
     "Last 30 days" : "Síðustu 30 daga",
     "This year" : "Á þessu ári",
     "Last year" : "Á síðasta ári",
+    "Between {startDate} and {endDate}" : "Milli {startDate} og {endDate}",
     "Unified search" : "Sameinuð leit",
     "Search apps, files, tags, messages" : "Leita í forritum, skrám, merkjum, skilaboðum",
     "Places" : "Staðir",
@@ -133,11 +243,12 @@ OC.L10N.register(
     "Search people" : "Leita að fólki",
     "People" : "Fólk",
     "Filter in current view" : "Sía í núverandi sýn",
+    "Search connected services" : "Leita að tengdum þjónustum",
     "Results" : "Niðurstöður",
     "Load more results" : "Hlaða inn fleiri niðurstöðum",
     "Search in" : "Leita í",
     "Log in" : "Skrá inn",
-    "Logging in …" : "Skrái inn …",
+    "Logging in …" : "Skrái inn …",
     "Log in to {productName}" : "Skrá inn í {productName}",
     "Wrong login or password." : "Rangur notandi eða lykilorð.",
     "This account is disabled" : "Þessi notandaaðgangur er óvirkur",
@@ -146,8 +257,8 @@ OC.L10N.register(
     "Account name" : "Heiti notandaaðgangs",
     "Server side authentication failed!" : "Auðkenning af hálfu þjóns tókst ekki!",
     "Please contact your administrator." : "Hafðu samband við kerfisstjóra.",
-    "Temporary error" : "Tímabundin villa",
-    "Please try again." : "Endilega reyndu aftur.",
+    "Session error" : "Villa í setu",
+    "It appears your session token has expired, please refresh the page and try again." : "Það lítur út fyrir að setuteiknið þitt sé útrunnð, endurlestu síðuna og prófaðu aftur.",
     "An internal error occurred." : "Innri villa kom upp.",
     "Please try again or contact your administrator." : "Reyndu aftur eða hafðu samband við kerfisstjóra.",
     "Password" : "Lykilorð",
@@ -174,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Skjöl í samstarfsvinnslu, töflureiknar og kynningar, byggt á Collabora Online.",
     "Distraction free note taking app." : "Glósuforrit án truflana.",
     "Recommended apps" : "Ráðlögð forrit",
-    "Loading apps …" : "Hleð inn forritum …",
+    "Loading apps …" : "Hleð inn forritum …",
     "Could not fetch list of apps from the App Store." : "Gat ekki sótt lista yfir forrit úr App Store.",
     "App download or installation failed" : "Niðurhal eða uppsetning forrits mistókst",
     "Cannot install this app because it is not compatible" : "Ekki er hægt að setja upp forritið því það er ekki samhæft",
     "Cannot install this app" : "Get ekki sett upp þetta forrit",
     "Skip" : "Sleppa",
-    "Installing apps …" : "Set upp forrit …",
+    "Installing apps …" : "Set upp forrit …",
     "Install recommended apps" : "Setja upp ráðlögð forrit",
     "Avatar of {displayName}" : "Auðkennismynd fyrir {displayName}",
     "Settings menu" : "Stillingavalmynd",
-    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
-    "Looking for {term} …" : "Leita að {term} …",
+    "Loading your contacts …" : "Hleð inn tengiliðum …",
+    "Looking for {term} …" : "Leita að {term} …",
     "Search contacts" : "Leita í tengiliðum",
     "Reset search" : "Núllstilla leit",
-    "Search contacts …" : "Leita í tengiliðum ",
+    "Search contacts …" : "Leita í tengiliðum …",
     "Could not load your contacts" : "Gat ekki hlaðið inn tengiliðalistanum þínum",
     "No contacts found" : "Engir tengiliðir fundust",
     "Show all contacts" : "Birta alla tengiliði ...",
@@ -200,16 +311,37 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Villa kom upp við leit að {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Leitin hefst um leið og byrjað er að skrifa og er hægt að flakka um leitarniðurstöður með örvalyklunum",
     "Search for {name} only" : "Leita einungis að {name}",
-    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
+    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
     "Forgot password?" : "Gleymdirðu lykilorði?",
     "Back to login form" : "Til baka í innskráningarform",
     "Back" : "Til baka",
     "Login form is disabled." : "Innskráningarform er óvirkt.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Innskráningarform Nextcloud er óvirkt. Notaðu aðra aðferð til innskráningar ef slíkt er í boði eða hafðu samband við kerfisstjórnanda.",
     "More actions" : "Fleiri aðgerðir",
+    "User menu" : "Valmynd notandans",
+    "Your guest name: {user}" : "Gestanafnið þitt: {user}",
+    "You are currently not identified." : "Þú ert ekki auðkennd/ur.",
+    "Set public name" : "Setja opinbert nafn",
+    "Change public name" : "Breyta opinberu nafni",
+    "Password is too weak" : "Lykilorð er of veikt",
+    "Password is weak" : "Lykilorð er veikt",
+    "Password is average" : "Lykilorð er í meðallagi",
+    "Password is strong" : "Lykilorð er sterkt",
+    "Password is very strong" : "Lykilorð er mjög sterkt",
+    "Password is extremely strong" : "Lykilorð er einstaklega sterkt",
+    "Unknown password strength" : "Óþekktur styrkur lykilorðs",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að <code>.htaccess</code> skráin er ekki virk.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Til að fá upplýsingar hvernig á að stilla miðlara almennilega, skaltu skoða {linkStart}hjálparskjölin{linkEnd}",
+    "Autoconfig file detected" : "Fann autoconfig-uppsetningarskrá",
+    "The setup form below is pre-filled with the values from the config file." : "Uppsetningrformið hér fyrir neðan er for-útfyllt með gildunum í config-skránni.",
     "Security warning" : "Öryggisviðvörun",
+    "Create administration account" : "Búa til stjórnunaraðgang",
+    "Administration account name" : "Heiti kerfisstjóraaðgangs",
+    "Administration account password" : "Lykilorð kerfisstjóraaðgangs",
     "Storage & database" : "Geymsla & gagnagrunnur",
     "Data folder" : "Gagnamappa",
+    "Database configuration" : "Uppsetning gagnagrunns",
+    "Only {firstAndOnlyDatabase} is available." : "Aðeins {firstAndOnlyDatabase} er laust.",
     "Install and activate additional PHP modules to choose other database types." : "Setja upp og virkja viðbótar PHP-einingar til að geta valið aðrar tegundir gagnagrunna.",
     "For more details check out the documentation." : "Frekari upplýsingar eru í hjálparskjölum.",
     "Performance warning" : "Afkastaviðvörun",
@@ -222,7 +354,8 @@ OC.L10N.register(
     "Database tablespace" : "Töflusvæði gagnagrunns",
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Taktu fram númer gáttar ásamt nafni hýsilvélar (t.d., localhost:5432).",
     "Database host" : "Netþjónn gagnagrunns",
-    "Installing …" : "Set upp…",
+    "localhost" : "localhost",
+    "Installing …" : "Set upp …",
     "Install" : "Setja upp",
     "Need help?" : "Þarftu hjálp?",
     "See the documentation" : "Sjá hjálparskjölin",
@@ -231,7 +364,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Það er ekki stuðningur við vafrann þinn. Endilega uppfærðu í nýrri útgáfu eða vafra sem er studdur.",
     "Continue with this unsupported browser" : "Halda áfram með þessum óstudda vafra",
     "Supported versions" : "Studdar útgáfur",
-    "Search {types} …" : "Leita að {types} …",
+    "Search {types} …" : "Leita að {types} …",
     "Choose {file}" : "Veldu {file}",
     "Choose" : "Veldu",
     "Copy to {target}" : "Afrita í {target}",
@@ -251,7 +384,7 @@ OC.L10N.register(
     "(all selected)" : "(allt valið)",
     "({count} selected)" : "({count} valið)",
     "Error loading file exists template" : "Villa við að hlaða inn sniðmáti fyrir skrá-er-til",
-    "Saving …" : "Vista …",
+    "Saving …" : "Vista …",
     "seconds ago" : "sekúndum síðan",
     "Connection to server lost" : "Tenging við miðlara rofnaði",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndu","Vandamál við að hlaða inn síðu, endurhleð eftir %n sekúndur"],
@@ -266,26 +399,18 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skrifaðu hér til að leita að fyrirliggjandi verkefnum",
     "New in" : "Nýtt í",
     "View changelog" : "Skoða breytingaannál",
-    "No action available" : "Engin aðgerð tiltæk",
-    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
     "Close \"{dialogTitle}\" dialog" : "Loka \"{dialogTitle}\"-glugga",
     "Email length is at max (255)" : "Lengd tölvupósts er að hámarki (255)",
-    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
-    "Restricted" : "Takmarkað",
-    "Invisible" : "Ósýnilegt",
-    "Delete" : "Eyða",
-    "Rename" : "Endurnefna",
-    "Collaborative tags" : "Samstarfsmerkingar",
-    "No tags found" : "Engin merki fundust",
     "Clipboard not available, please copy manually" : "Klippispjald er ekki tiltækt, afritaðu handvirkt",
     "Personal" : "Einka",
     "Accounts" : "Notandaaðgangar",
     "Admin" : "Stjórnun",
     "Help" : "Hjálp",
     "Access forbidden" : "Aðgangur bannaður",
+    "You are not allowed to access this page." : "Þú hefur ekki heimild til að skoða þessa síðu.",
+    "Back to %s" : "Til baka í %s",
     "Page not found" : "Síða fannst ekki",
     "The page could not be found on the server or you may not be allowed to view it." : "Síðan fannst ekki á netþjóninum eða að þér er ekki heimilt að skoða hana.",
-    "Back to %s" : "Til baka í %s",
     "Too many requests" : "Of margar beiðnir",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
     "Error" : "Villa",
@@ -361,21 +486,46 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Þessi %s er nú í viðhaldsham, sem getur tekið smá stund.",
     "This page will refresh itself when the instance is available again." : "Þessi síða mun uppfæra sig þegar tilvikið er í boði á ný.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Hafðu samband við kerfisstjóra ef þessi skilaboð eru viðvarandi eða birtust óvænt.",
-    "Currently open" : "Opið núna",
-    "Login with username or email" : "Skrá inn með notandanafni eða tölvupóstfangi",
-    "Login with username" : "Skrá inn með notandanafni",
+    "Error occurred while checking server setup" : "Villa kom upp við athugun á uppsetningu þjóns",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Frekari upplýsingar má sjá í {linkstart}hjálparskjölunum ↗{linkend}.",
+    "unknown text" : "óþekktur texti",
+    "Hello world!" : "Halló heimur!",
+    "sunny" : "sólríkt",
+    "Hello {name}, the weather is {weather}" : "Halló {name},veðrið er {weather}",
+    "Hello {name}" : "Halló {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Hér eru leitarniðurstöðurnar þínar<script>alert(1)</script></strong>",
+    "new" : "nýtt",
+    "_download %n file_::_download %n files_" : ["sækja %n skrá","sækja %n skrár"],
+    "Searching …" : "Leita …",
+    "Logging in …" : "Skrái inn …",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Spjall, myndfundir, skjádeiling, netfundir og vefráðstefnur – í vafranum þínum og með farsímaforritum.",
+    "Loading apps …" : "Hleð inn forritum …",
+    "Installing apps …" : "Set upp forrit …",
+    "Loading your contacts …" : "Hleð inn tengiliðalistum ...",
+    "Looking for {term} …" : "Leita að {term} …",
+    "Search contacts …" : "Leita í tengiliðum ",
+    "Loading more results …" : "Hleð inn fleiri niðurstöðum …",
     "You have not added any info yet" : "Þú hefur ekki bætt við neinum upplýsingum ennþá",
     "{user} has not added any info yet" : "{user} hefur ekki bætt við neinum upplýsingum ennþá",
     "Error opening the user status modal, try hard refreshing the page" : "Villa við að opna stöðuglugga notandans, prófaðu að þvinga endurlestur síðunnar",
     "Edit Profile" : "Breyta sniði",
     "The headline and about sections will show up here" : "Fyrirsögnin og hlutar um hugbúnaðinn munu birtast hér",
-    "Error loading message template: {error}" : "Villa við að hlaða inn sniðmáti fyrir skilaboð: {error}",
+    "Search {types} …" : "Leita að {types} …",
+    "Saving …" : "Vista …",
     "Very weak password" : "Mjög veikt lykilorð",
     "Weak password" : "Veikt lykilorð",
     "So-so password" : "Miðlungs lykilorð",
     "Good password" : "Gott lykilorð",
     "Strong password" : "Sterkt lykilorð",
+    "No action available" : "Engin aðgerð tiltæk",
+    "Error fetching contact actions" : "Villa við að sækja aðgerðir tengiliða",
+    "Non-existing tag #{tag}" : "Merki sem er ekki til #{tag}",
+    "Restricted" : "Takmarkað",
+    "Invisible" : "Ósýnilegt",
+    "Delete" : "Eyða",
+    "Rename" : "Endurnefna",
+    "Collaborative tags" : "Samstarfsmerkingar",
+    "No tags found" : "Engin merki fundust",
     "Profile not found" : "Sniðið finnst ekki",
     "The profile does not exist." : "Sniðið er ekki til.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Gagnamappan og skrárnar eru líklega aðgengilegar af internetinu vegna þess að .htaccess skrá er ekki virk.",
@@ -387,6 +537,8 @@ OC.L10N.register(
     "Toggle password visibility" : "Breyta sýnileika lykilorðs",
     "Configure the database" : "Stilla gagnagrunninn",
     "Only %s is available." : "Aðeins %s eru laus.",
-    "Database account" : "Gagnagrunnsaðgangur"
+    "Database account" : "Gagnagrunnsaðgangur",
+    "Installing …" : "Set upp…",
+    "Direct link copied to clipboard" : "Beinn tengill afritaður á klippispjald"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
