@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "Onbekend bestandsformaat",
     "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met je beheerder.",
     "Invalid image" : "Afbeelding ongeldig",
-    "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
-    "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
-    "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
-    "Crop is not square" : "Bijgesneden afbeelding is niet vierkant",
     "State token does not match" : "State-token komt niet overeen",
     "Invalid app password" : "Ongeldig appwachtwoord",
     "Could not complete login" : "De login kon niet worden voltooid",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "Geen provider voor vertaling beschikbaar",
     "Could not detect language" : "Kan taal niet detecteren",
     "Unable to translate" : "Niet mogelijk te vertalen",
+    "No valid filters provided" : "Geen geldige filters opgegeven",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Herstel stap:",
     "Repair info:" : "Herstel informatie:",
@@ -200,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska-video",
     "Windows Media video" : "Windows Media video",
     "AVI video" : "AVI-video",
-    "unknown text" : "onbekende tekst",
-    "Hello world!" : "Hallo wereld!",
-    "sunny" : "zonnig",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dit zijn je zoekresultaten<script>alert(1)</script></strong>",
-    "new" : "nieuw",
-    "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
     "Update to {version}" : "Geüpdatet naar {version}",
     "An error occurred." : "Er heeft zich een fout voorgedaan.",
@@ -237,14 +226,16 @@ OC.L10N.register(
     "Search in current app" : "Zoek in huidige app",
     "Clear search" : "Wis zoekvak",
     "Search everywhere" : "Zoek in alles",
-    "Searching …" : "Zoeken ...",
+    "Searching …" : "Zoeken ...",
     "Start typing to search" : "Begin met typen om te zoeken",
+    "Minimum search length is {minSearchLength} characters" : "Minimale lengte voor zoeken is {minSearchLength} tekens",
     "No matching results" : "Geen resultaten",
     "Today" : "Vandaag",
     "Last 7 days" : "Laatste 7 dagen",
     "Last 30 days" : "Laatste 30 dagen",
     "This year" : "Dit jaar",
     "Last year" : "Vorig jaar",
+    "Between {startDate} and {endDate}" : "Tussen {startDate} en {endDate}",
     "Unified search" : "Geünificeerd zoeken",
     "Search apps, files, tags, messages" : "Zoek apps, bestanden, berichten",
     "Places" : "Locaties",
@@ -257,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "Laad meer resultaten",
     "Search in" : "Zoek in",
     "Log in" : "Inloggen",
-    "Logging in …" : "Inloggen...",
+    "Logging in …" : "Aanmelden ...",
     "Log in to {productName}" : "Inloggen bij {productName}",
     "Wrong login or password." : "Verkeerde login of wachtwoord.",
     "This account is disabled" : "Dit account is uitgeschakeld",
@@ -294,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samenwerken aan tekst, spreadsheets en presentaties, gebouwt op basis van Collabora Online.",
     "Distraction free note taking app." : "Notitie app zonder afleiding.",
     "Recommended apps" : "Aanbevolen apps",
-    "Loading apps …" : "Laden apps ...",
+    "Loading apps …" : "Laden apps ...",
     "Could not fetch list of apps from the App Store." : "Kon lijst met apps niet ophalen vanuit de App Store.",
     "App download or installation failed" : "App download of installatie mislukt",
     "Cannot install this app because it is not compatible" : "Kan deze app niet installeren omdat deze niet compatible is",
     "Cannot install this app" : "Kan deze app niet installeren",
     "Skip" : "Overslaan",
-    "Installing apps …" : "Installeren apps …",
+    "Installing apps …" : "Installeren apps …",
     "Install recommended apps" : "Installeer aanbevolen apps",
     "Avatar of {displayName}" : "Avatar van {displayName}",
     "Settings menu" : "Instellingenmenu",
-    "Loading your contacts …" : "Je contacten wordt geladen ...",
-    "Looking for {term} …" : "Kijken voor {term} …",
+    "Loading your contacts …" : "Je contacten worden geladen ...",
+    "Looking for {term} …" : "Zoeken naar {term}",
     "Search contacts" : "Zoek contacten",
     "Reset search" : "Zoekopdracht wissen",
-    "Search contacts …" : "Zoek contacten ...",
+    "Search contacts …" : "Zoek contacten ...",
     "Could not load your contacts" : "Kon je contactpersonenen niet laden",
     "No contacts found" : "Geen contacten gevonden",
     "Show all contacts" : "Toon alle contactpersonen",
@@ -320,7 +311,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Er trad een fout op bij het zoeken naar {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Het zoeken begint wanneer je begint met typen en resultaten kunnen geselecteerd worden met de pijltjestoetsen",
     "Search for {name} only" : "Zoek alleen naar {name}",
-    "Loading more results …" : "Meer resultaten laden ...",
+    "Loading more results …" : "Meer resultaten laden ...",
     "Forgot password?" : "Wachtwoord vergeten?",
     "Back to login form" : "Terug naar aanmelden",
     "Back" : "Terug",
@@ -364,7 +355,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
     "Database host" : "Databaseserver",
     "localhost" : "localhost",
-    "Installing …" : "Installeren …",
+    "Installing …" : "Installeren …",
     "Install" : "Installeren",
     "Need help?" : "Hulp nodig?",
     "See the documentation" : "Zie de documentatie",
@@ -373,7 +364,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Deze browser wordt niet ondersteunt. Upgrade a.u.b naar een nieuwere versie of een browser die wel ondersteunt wordt.",
     "Continue with this unsupported browser" : "Ga verder met deze niet-ondersteunde browser",
     "Supported versions" : "Ondersteunde versies",
-    "Search {types} …" : "Zoeken naar {types}…",
+    "Search {types} …" : "Zoeken naar {types}…",
     "Choose {file}" : "Kies {file}",
     "Choose" : "Kies",
     "Copy to {target}" : "Kopieer naar {target}",
@@ -393,7 +384,7 @@ OC.L10N.register(
     "(all selected)" : "(alles geselecteerd)",
     "({count} selected)" : "({count} geselecteerd)",
     "Error loading file exists template" : "Fout bij laden bestand bestaat al sjabloon",
-    "Saving …" : "Opslaan ...",
+    "Saving …" : "Opslaan ...",
     "seconds ago" : "seconden geleden",
     "Connection to server lost" : "Verbinding met server verbroken",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem met laden pagina, herladen over %n seconde","Probleem met laden pagina, herladen over %n seconden"],
@@ -408,17 +399,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "Type om bestaande projecten te vinden",
     "New in" : "Nieuw in",
     "View changelog" : "Bekijk wijzigingsoverzicht",
-    "No action available" : "Geen actie beschikbaar",
-    "Error fetching contact actions" : "Fout bij ophalen contact acties",
     "Close \"{dialogTitle}\" dialog" : "Sluit \"{dialogTitle}\" dialoog",
     "Email length is at max (255)" : "E-maillengte is op maximum (255)",
-    "Non-existing tag #{tag}" : "Niet bestaande markering #{tag}",
-    "Restricted" : "Beperkt",
-    "Invisible" : "Onzichtbaar",
-    "Delete" : "Verwijder",
-    "Rename" : "Naam wijzigen",
-    "Collaborative tags" : "Systeemtags",
-    "No tags found" : "Geen tags gevonden",
     "Clipboard not available, please copy manually" : "Klembord niet beschikbaar, kopieer handmatig a.u.b.",
     "Personal" : "Persoonlijk",
     "Accounts" : "Accounts",
@@ -506,17 +488,44 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met je systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
     "Error occurred while checking server setup" : "Een fout trad op bij controleren van serverconfiguratie",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Voor meer informatie word je verwezen naar de {linkstart}documentatie↗{linkend}.",
+    "unknown text" : "onbekende tekst",
+    "Hello world!" : "Hallo wereld!",
+    "sunny" : "zonnig",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dit zijn je zoekresultaten<script>alert(1)</script></strong>",
+    "new" : "nieuw",
+    "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
+    "Searching …" : "Zoeken ...",
+    "Logging in …" : "Inloggen...",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
+    "Loading apps …" : "Laden apps ...",
+    "Installing apps …" : "Installeren apps …",
+    "Loading your contacts …" : "Je contacten wordt geladen ...",
+    "Looking for {term} …" : "Kijken voor {term} …",
+    "Search contacts …" : "Zoek contacten ...",
+    "Loading more results …" : "Meer resultaten laden ...",
     "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
     "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
     "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
     "Edit Profile" : "Wijzig Profiel",
     "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
+    "Search {types} …" : "Zoeken naar {types}…",
+    "Saving …" : "Opslaan ...",
     "Very weak password" : "Zeer zwak wachtwoord",
     "Weak password" : "Zwak wachtwoord",
     "So-so password" : "Matig wachtwoord",
     "Good password" : "Goed wachtwoord",
     "Strong password" : "Sterk wachtwoord",
+    "No action available" : "Geen actie beschikbaar",
+    "Error fetching contact actions" : "Fout bij ophalen contact acties",
+    "Non-existing tag #{tag}" : "Niet bestaande markering #{tag}",
+    "Restricted" : "Beperkt",
+    "Invisible" : "Onzichtbaar",
+    "Delete" : "Verwijder",
+    "Rename" : "Naam wijzigen",
+    "Collaborative tags" : "Systeemtags",
+    "No tags found" : "Geen tags gevonden",
     "Profile not found" : "Profiel niet gevonden",
     "The profile does not exist." : "Het profiel bestaat niet.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
@@ -529,6 +538,7 @@ OC.L10N.register(
     "Configure the database" : "Configureer de database",
     "Only %s is available." : "Alleen %s is beschikbaar.",
     "Database account" : "Database account",
+    "Installing …" : "Installeren …",
     "Direct link copied to clipboard" : "Directe link gekopieerd naar klembord"
 },
 "nplurals=2; plural=(n != 1);");
